"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .productupdate import ProductUpdate, ProductUpdateTypedDict
from polar_sdk.types import BaseModel
from polar_sdk.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing import TypedDict
from typing_extensions import Annotated


class ProductsUpdateRequestTypedDict(TypedDict):
    id: str
    product_update: ProductUpdateTypedDict


class ProductsUpdateRequest(BaseModel):
    id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]

    product_update: Annotated[
        ProductUpdate,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .downloadablefileread import DownloadableFileRead, DownloadableFileReadTypedDict
from .organizationavatarfileread import (
    OrganizationAvatarFileRead,
    OrganizationAvatarFileReadTypedDict,
)
from .pagination import Pagination, PaginationTypedDict
from .productmediafileread_output import (
    ProductMediaFileReadOutput,
    ProductMediaFileReadOutputTypedDict,
)
from polar_sdk.types import BaseModel
from polar_sdk.utils import get_discriminator
from pydantic import Discriminator, Tag
from typing import List, TypedDict, Union
from typing_extensions import Annotated


FileReadTypedDict = Union[
    DownloadableFileReadTypedDict,
    ProductMediaFileReadOutputTypedDict,
    OrganizationAvatarFileReadTypedDict,
]


FileRead = Annotated[
    Union[
        Annotated[DownloadableFileRead, Tag("downloadable")],
        Annotated[OrganizationAvatarFileRead, Tag("organization_avatar")],
        Annotated[ProductMediaFileReadOutput, Tag("product_media")],
    ],
    Discriminator(lambda m: get_discriminator(m, "service", "service")),
]


class ListResourceFileReadTypedDict(TypedDict):
    items: List[FileReadTypedDict]
    pagination: PaginationTypedDict


class ListResourceFileRead(BaseModel):
    items: List[FileRead]

    pagination: Pagination



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum
from polar_sdk.types import BaseModel, Nullable, OptionalNullable, UNSET, UNSET_SENTINEL
from polar_sdk.utils import FieldMetadata
from pydantic import model_serializer
from typing import TypedDict
from typing_extensions import Annotated, NotRequired


class TokenTypeHint(str, Enum):
    ACCESS_TOKEN = "access_token"
    REFRESH_TOKEN = "refresh_token"


class Oauth2RevokeTokenRevokeTokenRequestTypedDict(TypedDict):
    token: str
    client_id: str
    client_secret: str
    token_type_hint: NotRequired[Nullable[TokenTypeHint]]


class Oauth2RevokeTokenRevokeTokenRequest(BaseModel):
    token: Annotated[str, FieldMetadata(form=True)]

    client_id: Annotated[str, FieldMetadata(form=True)]

    client_secret: Annotated[str, FieldMetadata(form=True)]

    token_type_hint: Annotated[
        OptionalNullable[TokenTypeHint], FieldMetadata(form=True)
    ] = UNSET

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["token_type_hint"]
        nullable_fields = ["token_type_hint"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in self.model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .listresource_userorder_ import (
    ListResourceUserOrder,
    ListResourceUserOrderTypedDict,
)
from .productpricetype import ProductPriceType
from .userordersortproperty import UserOrderSortProperty
from polar_sdk.types import BaseModel, Nullable, OptionalNullable, UNSET, UNSET_SENTINEL
from polar_sdk.utils import FieldMetadata, QueryParamMetadata
from pydantic import model_serializer
from typing import Callable, List, Optional, TypedDict, Union
from typing_extensions import Annotated, NotRequired


QueryParamOrganizationIDFilterTypedDict = Union[str, List[str]]
r"""Filter by organization ID."""


QueryParamOrganizationIDFilter = Union[str, List[str]]
r"""Filter by organization ID."""


ProductIDFilterTypedDict = Union[str, List[str]]
r"""Filter by product ID."""


ProductIDFilter = Union[str, List[str]]
r"""Filter by product ID."""


ProductPriceTypeFilterTypedDict = Union[ProductPriceType, List[ProductPriceType]]
r"""Filter by product price type. `recurring` will return orders corresponding to subscriptions creations or renewals. `one_time` will return orders corresponding to one-time purchases."""


ProductPriceTypeFilter = Union[ProductPriceType, List[ProductPriceType]]
r"""Filter by product price type. `recurring` will return orders corresponding to subscriptions creations or renewals. `one_time` will return orders corresponding to one-time purchases."""


QueryParamSubscriptionIDFilterTypedDict = Union[str, List[str]]
r"""Filter by subscription ID."""


QueryParamSubscriptionIDFilter = Union[str, List[str]]
r"""Filter by subscription ID."""


class UsersOrdersListRequestTypedDict(TypedDict):
    organization_id: NotRequired[Nullable[QueryParamOrganizationIDFilterTypedDict]]
    r"""Filter by organization ID."""
    product_id: NotRequired[Nullable[ProductIDFilterTypedDict]]
    r"""Filter by product ID."""
    product_price_type: NotRequired[Nullable[ProductPriceTypeFilterTypedDict]]
    r"""Filter by product price type. `recurring` will return orders corresponding to subscriptions creations or renewals. `one_time` will return orders corresponding to one-time purchases."""
    subscription_id: NotRequired[Nullable[QueryParamSubscriptionIDFilterTypedDict]]
    r"""Filter by subscription ID."""
    query: NotRequired[Nullable[str]]
    r"""Search by product or organization name."""
    page: NotRequired[int]
    r"""Page number, defaults to 1."""
    limit: NotRequired[int]
    r"""Size of a page, defaults to 10. Maximum is 100."""
    sorting: NotRequired[Nullable[List[UserOrderSortProperty]]]
    r"""Sorting criterion. Several criteria can be used simultaneously and will be applied in order. Add a minus sign `-` before the criteria name to sort by descending order."""


class UsersOrdersListRequest(BaseModel):
    organization_id: Annotated[
        OptionalNullable[QueryParamOrganizationIDFilter],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = UNSET
    r"""Filter by organization ID."""

    product_id: Annotated[
        OptionalNullable[ProductIDFilter],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = UNSET
    r"""Filter by product ID."""

    product_price_type: Annotated[
        OptionalNullable[ProductPriceTypeFilter],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = UNSET
    r"""Filter by product price type. `recurring` will return orders corresponding to subscriptions creations or renewals. `one_time` will return orders corresponding to one-time purchases."""

    subscription_id: Annotated[
        OptionalNullable[QueryParamSubscriptionIDFilter],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = UNSET
    r"""Filter by subscription ID."""

    query: Annotated[
        OptionalNullable[str],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = UNSET
    r"""Search by product or organization name."""

    page: Annotated[
        Optional[int],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = 1
    r"""Page number, defaults to 1."""

    limit: Annotated[
        Optional[int],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = 10
    r"""Size of a page, defaults to 10. Maximum is 100."""

    sorting: Annotated[
        OptionalNullable[List[UserOrderSortProperty]],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = UNSET
    r"""Sorting criterion. Several criteria can be used simultaneously and will be applied in order. Add a minus sign `-` before the criteria name to sort by descending order."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = [
            "organization_id",
            "product_id",
            "product_price_type",
            "subscription_id",
            "query",
            "page",
            "limit",
            "sorting",
        ]
        nullable_fields = [
            "organization_id",
            "product_id",
            "product_price_type",
            "subscription_id",
            "query",
            "sorting",
        ]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in self.model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m


class UsersOrdersListResponseTypedDict(TypedDict):
    result: ListResourceUserOrderTypedDict


class UsersOrdersListResponse(BaseModel):
    next: Callable[[], Optional[UsersOrdersListResponse]]

    result: ListResourceUserOrder



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .benefitadssubscriber import BenefitAdsSubscriber, BenefitAdsSubscriberTypedDict
from .benefitarticlessubscriber import (
    BenefitArticlesSubscriber,
    BenefitArticlesSubscriberTypedDict,
)
from .benefitcustomsubscriber import (
    BenefitCustomSubscriber,
    BenefitCustomSubscriberTypedDict,
)
from .benefitdiscordsubscriber import (
    BenefitDiscordSubscriber,
    BenefitDiscordSubscriberTypedDict,
)
from .benefitdownloadablessubscriber import (
    BenefitDownloadablesSubscriber,
    BenefitDownloadablesSubscriberTypedDict,
)
from .benefitgithubrepositorysubscriber import (
    BenefitGitHubRepositorySubscriber,
    BenefitGitHubRepositorySubscriberTypedDict,
)
from .benefitlicensekeyssubscriber import (
    BenefitLicenseKeysSubscriber,
    BenefitLicenseKeysSubscriberTypedDict,
)
from .pagination import Pagination, PaginationTypedDict
from polar_sdk.types import BaseModel
from polar_sdk.utils import get_discriminator
from pydantic import Discriminator, Tag
from typing import List, TypedDict, Union
from typing_extensions import Annotated


UserBenefitTypedDict = Union[
    BenefitArticlesSubscriberTypedDict,
    BenefitDiscordSubscriberTypedDict,
    BenefitGitHubRepositorySubscriberTypedDict,
    BenefitDownloadablesSubscriberTypedDict,
    BenefitAdsSubscriberTypedDict,
    BenefitCustomSubscriberTypedDict,
    BenefitLicenseKeysSubscriberTypedDict,
]


UserBenefit = Annotated[
    Union[
        Annotated[BenefitAdsSubscriber, Tag("ads")],
        Annotated[BenefitArticlesSubscriber, Tag("articles")],
        Annotated[BenefitCustomSubscriber, Tag("custom")],
        Annotated[BenefitDiscordSubscriber, Tag("discord")],
        Annotated[BenefitDownloadablesSubscriber, Tag("downloadables")],
        Annotated[BenefitGitHubRepositorySubscriber, Tag("github_repository")],
        Annotated[BenefitLicenseKeysSubscriber, Tag("license_keys")],
    ],
    Discriminator(lambda m: get_discriminator(m, "type", "type")),
]


class ListResourceUserBenefitTypedDict(TypedDict):
    items: List[UserBenefitTypedDict]
    pagination: PaginationTypedDict


class ListResourceUserBenefit(BaseModel):
    items: List[UserBenefit]

    pagination: Pagination



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from polar_sdk.types import BaseModel, Nullable, OptionalNullable, UNSET, UNSET_SENTINEL
from pydantic import model_serializer
from typing import TypedDict
from typing_extensions import NotRequired


class CheckoutCreateTypedDict(TypedDict):
    product_price_id: str
    r"""ID of the product price to subscribe to."""
    success_url: str
    r"""URL where the customer will be redirected after a successful subscription. You can add the `session_id={CHECKOUT_SESSION_ID}` query parameter to retrieve the checkout session id."""
    customer_email: NotRequired[Nullable[str]]
    r"""If you already know the email of your customer, you can set it. It'll be pre-filled on the checkout page."""


class CheckoutCreate(BaseModel):
    product_price_id: str
    r"""ID of the product price to subscribe to."""

    success_url: str
    r"""URL where the customer will be redirected after a successful subscription. You can add the `session_id={CHECKOUT_SESSION_ID}` query parameter to retrieve the checkout session id."""

    customer_email: OptionalNullable[str] = UNSET
    r"""If you already know the email of your customer, you can set it. It'll be pre-filled on the checkout page."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["customer_email"]
        nullable_fields = ["customer_email"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in self.model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum
from polar_sdk.types import BaseModel
import pydantic
from typing import Final, TypedDict
from typing_extensions import Annotated


class ProductPriceOneTimeFreeCreateType(str, Enum):
    ONE_TIME = "one_time"


class ProductPriceOneTimeFreeCreateAmountType(str, Enum):
    FREE = "free"


class ProductPriceOneTimeFreeCreateTypedDict(TypedDict):
    r"""Schema to create a free one-time product price."""

    type: ProductPriceOneTimeFreeCreateType
    amount_type: ProductPriceOneTimeFreeCreateAmountType


class ProductPriceOneTimeFreeCreate(BaseModel):
    r"""Schema to create a free one-time product price."""

    # fmt: off
    TYPE: Annotated[Final[ProductPriceOneTimeFreeCreateType], pydantic.Field(alias="type")] = ProductPriceOneTimeFreeCreateType.ONE_TIME # type: ignore
    # fmt: on

    # fmt: off
    AMOUNT_TYPE: Annotated[Final[ProductPriceOneTimeFreeCreateAmountType], pydantic.Field(alias="amount_type")] = ProductPriceOneTimeFreeCreateAmountType.FREE # type: ignore
    # fmt: on



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from .basesdk import BaseSDK
from .sdkconfiguration import SDKConfiguration
from polar_sdk import models, utils
from polar_sdk._hooks import HookContext
from polar_sdk.clients import Clients
from polar_sdk.types import BaseModel, OptionalNullable, UNSET
from typing import Optional, Union, cast


class Oauth2(BaseSDK):
    clients: Clients

    def __init__(self, sdk_config: SDKConfiguration) -> None:
        BaseSDK.__init__(self, sdk_config)
        self.sdk_configuration = sdk_config
        self._init_sdks()

    def _init_sdks(self):
        self.clients = Clients(self.sdk_configuration)

    def token(
        self,
        *,
        request: Union[
            models.Oauth2RequestTokenRequestBody,
            models.Oauth2RequestTokenRequestBodyTypedDict,
        ],
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
    ) -> Optional[models.TokenResponse]:
        r"""Request Token

        Request an access token using a valid grant.

        :param request: The request object to send.
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url

        if not isinstance(request, BaseModel):
            request = utils.unmarshal(request, models.Oauth2RequestTokenRequestBody)
        request = cast(models.Oauth2RequestTokenRequestBody, request)

        req = self.build_request(
            method="POST",
            path="/v1/oauth2/token",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request, False, False, "form", models.Oauth2RequestTokenRequestBody
            ),
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                operation_id="oauth2:request_token",
                oauth2_scopes=[],
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=["4XX", "5XX"],
            retry_config=retry_config,
        )

        if utils.match_response(http_res, "200", "application/json"):
            return utils.unmarshal_json(http_res.text, Optional[models.TokenResponse])
        if utils.match_response(http_res, ["4XX", "5XX"], "*"):
            raise models.SDKError(
                "API error occurred", http_res.status_code, http_res.text, http_res
            )

        content_type = http_res.headers.get("Content-Type")
        raise models.SDKError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res.text,
            http_res,
        )

    async def token_async(
        self,
        *,
        request: Union[
            models.Oauth2RequestTokenRequestBody,
            models.Oauth2RequestTokenRequestBodyTypedDict,
        ],
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
    ) -> Optional[models.TokenResponse]:
        r"""Request Token

        Request an access token using a valid grant.

        :param request: The request object to send.
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url

        if not isinstance(request, BaseModel):
            request = utils.unmarshal(request, models.Oauth2RequestTokenRequestBody)
        request = cast(models.Oauth2RequestTokenRequestBody, request)

        req = self.build_request_async(
            method="POST",
            path="/v1/oauth2/token",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request, False, False, "form", models.Oauth2RequestTokenRequestBody
            ),
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                operation_id="oauth2:request_token",
                oauth2_scopes=[],
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=["4XX", "5XX"],
            retry_config=retry_config,
        )

        if utils.match_response(http_res, "200", "application/json"):
            return utils.unmarshal_json(http_res.text, Optional[models.TokenResponse])
        if utils.match_response(http_res, ["4XX", "5XX"], "*"):
            raise models.SDKError(
                "API error occurred", http_res.status_code, http_res.text, http_res
            )

        content_type = http_res.headers.get("Content-Type")
        raise models.SDKError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res.text,
            http_res,
        )

    def revoke(
        self,
        *,
        request: Union[
            models.Oauth2RevokeTokenRevokeTokenRequest,
            models.Oauth2RevokeTokenRevokeTokenRequestTypedDict,
        ],
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
    ) -> Optional[models.RevokeTokenResponse]:
        r"""Revoke Token

        Revoke an access token or a refresh token.

        :param request: The request object to send.
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url

        if not isinstance(request, BaseModel):
            request = utils.unmarshal(
                request, models.Oauth2RevokeTokenRevokeTokenRequest
            )
        request = cast(models.Oauth2RevokeTokenRevokeTokenRequest, request)

        req = self.build_request(
            method="POST",
            path="/v1/oauth2/revoke",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request,
                False,
                False,
                "form",
                models.Oauth2RevokeTokenRevokeTokenRequest,
            ),
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                operation_id="oauth2:revoke_token",
                oauth2_scopes=[],
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=["4XX", "5XX"],
            retry_config=retry_config,
        )

        if utils.match_response(http_res, "200", "application/json"):
            return utils.unmarshal_json(
                http_res.text, Optional[models.RevokeTokenResponse]
            )
        if utils.match_response(http_res, ["4XX", "5XX"], "*"):
            raise models.SDKError(
                "API error occurred", http_res.status_code, http_res.text, http_res
            )

        content_type = http_res.headers.get("Content-Type")
        raise models.SDKError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res.text,
            http_res,
        )

    async def revoke_async(
        self,
        *,
        request: Union[
            models.Oauth2RevokeTokenRevokeTokenRequest,
            models.Oauth2RevokeTokenRevokeTokenRequestTypedDict,
        ],
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
    ) -> Optional[models.RevokeTokenResponse]:
        r"""Revoke Token

        Revoke an access token or a refresh token.

        :param request: The request object to send.
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url

        if not isinstance(request, BaseModel):
            request = utils.unmarshal(
                request, models.Oauth2RevokeTokenRevokeTokenRequest
            )
        request = cast(models.Oauth2RevokeTokenRevokeTokenRequest, request)

        req = self.build_request_async(
            method="POST",
            path="/v1/oauth2/revoke",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request,
                False,
                False,
                "form",
                models.Oauth2RevokeTokenRevokeTokenRequest,
            ),
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                operation_id="oauth2:revoke_token",
                oauth2_scopes=[],
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=["4XX", "5XX"],
            retry_config=retry_config,
        )

        if utils.match_response(http_res, "200", "application/json"):
            return utils.unmarshal_json(
                http_res.text, Optional[models.RevokeTokenResponse]
            )
        if utils.match_response(http_res, ["4XX", "5XX"], "*"):
            raise models.SDKError(
                "API error occurred", http_res.status_code, http_res.text, http_res
            )

        content_type = http_res.headers.get("Content-Type")
        raise models.SDKError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res.text,
            http_res,
        )

    def introspect(
        self,
        *,
        request: Union[
            models.Oauth2IntrospectTokenIntrospectTokenRequest,
            models.Oauth2IntrospectTokenIntrospectTokenRequestTypedDict,
        ],
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
    ) -> Optional[models.IntrospectTokenResponse]:
        r"""Introspect Token

        Get information about an access token.

        :param request: The request object to send.
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url

        if not isinstance(request, BaseModel):
            request = utils.unmarshal(
                request, models.Oauth2IntrospectTokenIntrospectTokenRequest
            )
        request = cast(models.Oauth2IntrospectTokenIntrospectTokenRequest, request)

        req = self.build_request(
            method="POST",
            path="/v1/oauth2/introspect",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request,
                False,
                False,
                "form",
                models.Oauth2IntrospectTokenIntrospectTokenRequest,
            ),
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                operation_id="oauth2:introspect_token",
                oauth2_scopes=[],
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=["4XX", "5XX"],
            retry_config=retry_config,
        )

        if utils.match_response(http_res, "200", "application/json"):
            return utils.unmarshal_json(
                http_res.text, Optional[models.IntrospectTokenResponse]
            )
        if utils.match_response(http_res, ["4XX", "5XX"], "*"):
            raise models.SDKError(
                "API error occurred", http_res.status_code, http_res.text, http_res
            )

        content_type = http_res.headers.get("Content-Type")
        raise models.SDKError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res.text,
            http_res,
        )

    async def introspect_async(
        self,
        *,
        request: Union[
            models.Oauth2IntrospectTokenIntrospectTokenRequest,
            models.Oauth2IntrospectTokenIntrospectTokenRequestTypedDict,
        ],
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
    ) -> Optional[models.IntrospectTokenResponse]:
        r"""Introspect Token

        Get information about an access token.

        :param request: The request object to send.
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url

        if not isinstance(request, BaseModel):
            request = utils.unmarshal(
                request, models.Oauth2IntrospectTokenIntrospectTokenRequest
            )
        request = cast(models.Oauth2IntrospectTokenIntrospectTokenRequest, request)

        req = self.build_request_async(
            method="POST",
            path="/v1/oauth2/introspect",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request,
                False,
                False,
                "form",
                models.Oauth2IntrospectTokenIntrospectTokenRequest,
            ),
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                operation_id="oauth2:introspect_token",
                oauth2_scopes=[],
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=["4XX", "5XX"],
            retry_config=retry_config,
        )

        if utils.match_response(http_res, "200", "application/json"):
            return utils.unmarshal_json(
                http_res.text, Optional[models.IntrospectTokenResponse]
            )
        if utils.match_response(http_res, ["4XX", "5XX"], "*"):
            raise models.SDKError(
                "API error occurred", http_res.status_code, http_res.text, http_res
            )

        content_type = http_res.headers.get("Content-Type")
        raise models.SDKError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res.text,
            http_res,
        )

    def userinfo(
        self,
        *,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
    ) -> Optional[models.Oauth2UserinfoResponseOauth2Userinfo]:
        r"""Get User Info

        Get information about the authenticated user.

        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        req = self.build_request(
            method="GET",
            path="/v1/oauth2/userinfo",
            base_url=base_url,
            url_variables=url_variables,
            request=None,
            request_body_required=False,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            security=self.sdk_configuration.security,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                operation_id="oauth2:userinfo",
                oauth2_scopes=[],
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=["4XX", "5XX"],
            retry_config=retry_config,
        )

        if utils.match_response(http_res, "200", "application/json"):
            return utils.unmarshal_json(
                http_res.text, Optional[models.Oauth2UserinfoResponseOauth2Userinfo]
            )
        if utils.match_response(http_res, ["4XX", "5XX"], "*"):
            raise models.SDKError(
                "API error occurred", http_res.status_code, http_res.text, http_res
            )

        content_type = http_res.headers.get("Content-Type")
        raise models.SDKError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res.text,
            http_res,
        )

    async def userinfo_async(
        self,
        *,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
    ) -> Optional[models.Oauth2UserinfoResponseOauth2Userinfo]:
        r"""Get User Info

        Get information about the authenticated user.

        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        req = self.build_request_async(
            method="GET",
            path="/v1/oauth2/userinfo",
            base_url=base_url,
            url_variables=url_variables,
            request=None,
            request_body_required=False,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            security=self.sdk_configuration.security,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                operation_id="oauth2:userinfo",
                oauth2_scopes=[],
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=["4XX", "5XX"],
            retry_config=retry_config,
        )

        if utils.match_response(http_res, "200", "application/json"):
            return utils.unmarshal_json(
                http_res.text, Optional[models.Oauth2UserinfoResponseOauth2Userinfo]
            )
        if utils.match_response(http_res, ["4XX", "5XX"], "*"):
            raise models.SDKError(
                "API error occurred", http_res.status_code, http_res.text, http_res
            )

        content_type = http_res.headers.get("Content-Type")
        raise models.SDKError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res.text,
            http_res,
        )



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .assignee import Assignee, AssigneeTypedDict
from .author import Author, AuthorTypedDict
from .funding import Funding, FundingTypedDict
from .label import Label, LabelTypedDict
from .platforms import Platforms
from .reactions import Reactions, ReactionsTypedDict
from .repository_input import RepositoryInput, RepositoryInputTypedDict
from .state import State
from datetime import datetime
from polar_sdk.types import BaseModel, Nullable, OptionalNullable, UNSET, UNSET_SENTINEL
import pydantic
from pydantic import model_serializer
from typing import Final, List, Optional, TypedDict
from typing_extensions import Annotated, NotRequired


class IssueInputTypedDict(TypedDict):
    id: str
    number: int
    r"""GitHub #number"""
    title: str
    r"""GitHub issue title"""
    state: State
    issue_created_at: datetime
    needs_confirmation_solved: bool
    r"""If a maintainer needs to mark this issue as solved"""
    funding: FundingTypedDict
    repository: RepositoryInputTypedDict
    r"""The repository that the issue is in"""
    pledge_badge_currently_embedded: bool
    r"""If this issue currently has the Polar badge SVG embedded"""
    platform: Platforms
    r"""Issue platform (currently always GitHub)"""
    body: NotRequired[Nullable[str]]
    r"""GitHub issue body"""
    comments: NotRequired[Nullable[int]]
    r"""Number of GitHub comments made on the issue"""
    labels: NotRequired[List[LabelTypedDict]]
    author: NotRequired[Nullable[AuthorTypedDict]]
    r"""GitHub author"""
    assignees: NotRequired[Nullable[List[AssigneeTypedDict]]]
    r"""GitHub assignees"""
    reactions: NotRequired[Nullable[ReactionsTypedDict]]
    r"""GitHub reactions"""
    issue_closed_at: NotRequired[Nullable[datetime]]
    issue_modified_at: NotRequired[Nullable[datetime]]
    confirmed_solved_at: NotRequired[Nullable[datetime]]
    r"""If this issue has been marked as confirmed solved through Polar"""
    upfront_split_to_contributors: NotRequired[Nullable[int]]
    r"""Share of rewrads that will be rewarded to contributors of this issue. A number between 0 and 100 (inclusive)."""
    badge_custom_content: NotRequired[Nullable[str]]
    r"""Optional custom badge SVG promotional content"""


class IssueInput(BaseModel):
    id: str

    number: int
    r"""GitHub #number"""

    title: str
    r"""GitHub issue title"""

    state: State

    issue_created_at: datetime

    needs_confirmation_solved: bool
    r"""If a maintainer needs to mark this issue as solved"""

    funding: Funding

    repository: RepositoryInput
    r"""The repository that the issue is in"""

    pledge_badge_currently_embedded: bool
    r"""If this issue currently has the Polar badge SVG embedded"""

    # fmt: off
    PLATFORM: Annotated[Final[Platforms], pydantic.Field(alias="platform")] = Platforms.GITHUB # type: ignore
    # fmt: on
    r"""Issue platform (currently always GitHub)"""

    body: OptionalNullable[str] = UNSET
    r"""GitHub issue body"""

    comments: OptionalNullable[int] = UNSET
    r"""Number of GitHub comments made on the issue"""

    labels: Optional[List[Label]] = None

    author: OptionalNullable[Author] = UNSET
    r"""GitHub author"""

    assignees: OptionalNullable[List[Assignee]] = UNSET
    r"""GitHub assignees"""

    reactions: OptionalNullable[Reactions] = UNSET
    r"""GitHub reactions"""

    issue_closed_at: OptionalNullable[datetime] = UNSET

    issue_modified_at: OptionalNullable[datetime] = UNSET

    confirmed_solved_at: OptionalNullable[datetime] = UNSET
    r"""If this issue has been marked as confirmed solved through Polar"""

    upfront_split_to_contributors: OptionalNullable[int] = UNSET
    r"""Share of rewrads that will be rewarded to contributors of this issue. A number between 0 and 100 (inclusive)."""

    badge_custom_content: OptionalNullable[str] = UNSET
    r"""Optional custom badge SVG promotional content"""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = [
            "body",
            "comments",
            "labels",
            "author",
            "assignees",
            "reactions",
            "issue_closed_at",
            "issue_modified_at",
            "confirmed_solved_at",
            "upfront_split_to_contributors",
            "badge_custom_content",
        ]
        nullable_fields = [
            "body",
            "comments",
            "author",
            "assignees",
            "reactions",
            "issue_closed_at",
            "issue_modified_at",
            "confirmed_solved_at",
            "upfront_split_to_contributors",
            "badge_custom_content",
        ]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in self.model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from polar_sdk.types import BaseModel
from typing import Dict, List, Optional, TypedDict
from typing_extensions import NotRequired


class BenefitDownloadablesCreatePropertiesTypedDict(TypedDict):
    files: List[str]
    archived: NotRequired[Dict[str, bool]]


class BenefitDownloadablesCreateProperties(BaseModel):
    files: List[str]

    archived: Optional[Dict[str, bool]] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class SubscriptionStatus(str, Enum):
    INCOMPLETE = "incomplete"
    INCOMPLETE_EXPIRED = "incomplete_expired"
    TRIALING = "trialing"
    ACTIVE = "active"
    PAST_DUE = "past_due"
    CANCELED = "canceled"
    UNPAID = "unpaid"



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from polar_sdk.types import BaseModel
from typing import TypedDict


class BenefitGrantPropertiesTypedDict(TypedDict):
    r"""Properties for a benefit grant."""


class BenefitGrantProperties(BaseModel):
    r"""Properties for a benefit grant."""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .benefitads import BenefitAds, BenefitAdsTypedDict
from .benefitarticles import BenefitArticles, BenefitArticlesTypedDict
from .benefitcustom import BenefitCustom, BenefitCustomTypedDict
from .benefitdiscord_input import BenefitDiscordInput, BenefitDiscordInputTypedDict
from .benefitdownloadables import BenefitDownloadables, BenefitDownloadablesTypedDict
from .benefitgithubrepository import (
    BenefitGitHubRepository,
    BenefitGitHubRepositoryTypedDict,
)
from .benefitlicensekeys_input import (
    BenefitLicenseKeysInput,
    BenefitLicenseKeysInputTypedDict,
)
from enum import Enum
from polar_sdk.types import BaseModel
import pydantic
from typing import Final, TypedDict, Union
from typing_extensions import Annotated


class WebhookBenefitUpdatedPayloadType(str, Enum):
    BENEFIT_UPDATED = "benefit.updated"


WebhookBenefitUpdatedPayloadBenefitTypedDict = Union[
    BenefitArticlesTypedDict,
    BenefitAdsTypedDict,
    BenefitDiscordInputTypedDict,
    BenefitGitHubRepositoryTypedDict,
    BenefitDownloadablesTypedDict,
    BenefitLicenseKeysInputTypedDict,
    BenefitCustomTypedDict,
]


WebhookBenefitUpdatedPayloadBenefit = Union[
    BenefitArticles,
    BenefitAds,
    BenefitDiscordInput,
    BenefitGitHubRepository,
    BenefitDownloadables,
    BenefitLicenseKeysInput,
    BenefitCustom,
]


class WebhookBenefitUpdatedPayloadTypedDict(TypedDict):
    r"""Sent when a benefit is updated.

    **Discord & Slack support:** Basic
    """

    data: WebhookBenefitUpdatedPayloadBenefitTypedDict
    type: WebhookBenefitUpdatedPayloadType


class WebhookBenefitUpdatedPayload(BaseModel):
    r"""Sent when a benefit is updated.

    **Discord & Slack support:** Basic
    """

    data: WebhookBenefitUpdatedPayloadBenefit

    # fmt: off
    TYPE: Annotated[Final[WebhookBenefitUpdatedPayloadType], pydantic.Field(alias="type")] = WebhookBenefitUpdatedPayloadType.BENEFIT_UPDATED # type: ignore
    # fmt: on



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from polar_sdk.types import BaseModel
from typing import TypedDict


class BenefitGitHubRepositorySubscriberPropertiesTypedDict(TypedDict):
    r"""Properties available to subscribers for a benefit of type `github_repository`."""

    repository_owner: str
    r"""The owner of the repository."""
    repository_name: str
    r"""The name of the repository."""


class BenefitGitHubRepositorySubscriberProperties(BaseModel):
    r"""Properties available to subscribers for a benefit of type `github_repository`."""

    repository_owner: str
    r"""The owner of the repository."""

    repository_name: str
    r"""The name of the repository."""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .externalorganization import ExternalOrganization, ExternalOrganizationTypedDict
from .platforms import Platforms
from .repositoryprofilesettings import (
    RepositoryProfileSettings,
    RepositoryProfileSettingsTypedDict,
)
from polar_sdk.types import BaseModel, Nullable, UNSET_SENTINEL
import pydantic
from pydantic import model_serializer
from typing import Final, TypedDict
from typing_extensions import Annotated


class RepositoryInputTypedDict(TypedDict):
    id: str
    is_private: bool
    name: str
    description: Nullable[str]
    stars: Nullable[int]
    license: Nullable[str]
    homepage: Nullable[str]
    profile_settings: Nullable[RepositoryProfileSettingsTypedDict]
    r"""Settings for the repository profile"""
    organization: ExternalOrganizationTypedDict
    platform: Platforms


class RepositoryInput(BaseModel):
    id: str

    is_private: bool

    name: str

    description: Nullable[str]

    stars: Nullable[int]

    license: Nullable[str]

    homepage: Nullable[str]

    profile_settings: Nullable[RepositoryProfileSettings]
    r"""Settings for the repository profile"""

    organization: ExternalOrganization

    # fmt: off
    PLATFORM: Annotated[Final[Platforms], pydantic.Field(alias="platform")] = Platforms.GITHUB # type: ignore
    # fmt: on

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = []
        nullable_fields = [
            "description",
            "stars",
            "license",
            "homepage",
            "profile_settings",
        ]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in self.model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .donation_input import DonationInput, DonationInputTypedDict
from enum import Enum
from polar_sdk.types import BaseModel
import pydantic
from typing import Final, TypedDict
from typing_extensions import Annotated


class WebhookDonationCreatedPayloadType(str, Enum):
    DONATION_CREATED = "donation.created"


class WebhookDonationCreatedPayloadTypedDict(TypedDict):
    r"""Sent when a new donation is created.

    **Discord & Slack support:** Full
    """

    data: DonationInputTypedDict
    type: WebhookDonationCreatedPayloadType


class WebhookDonationCreatedPayload(BaseModel):
    r"""Sent when a new donation is created.

    **Discord & Slack support:** Full
    """

    data: DonationInput

    # fmt: off
    TYPE: Annotated[Final[WebhookDonationCreatedPayloadType], pydantic.Field(alias="type")] = WebhookDonationCreatedPayloadType.DONATION_CREATED # type: ignore
    # fmt: on



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class FileServiceTypes(str, Enum):
    DOWNLOADABLE = "downloadable"
    PRODUCT_MEDIA = "product_media"
    ORGANIZATION_AVATAR = "organization_avatar"



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from .advertisementcampaign import AdvertisementCampaign, AdvertisementCampaignTypedDict
from .advertisementcampaignlistresource import (
    AdvertisementCampaignListResource,
    AdvertisementCampaignListResourceTypedDict,
)
from .advertisements_getop import (
    AdvertisementsGetRequest,
    AdvertisementsGetRequestTypedDict,
)
from .advertisements_listop import (
    AdvertisementsListRequest,
    AdvertisementsListRequestTypedDict,
    AdvertisementsListResponse,
    AdvertisementsListResponseTypedDict,
)
from .advertisementsortproperty import AdvertisementSortProperty
from .alreadycanceledsubscription import (
    AlreadyCanceledSubscription,
    AlreadyCanceledSubscriptionData,
    AlreadyCanceledSubscriptionType,
)
from .article import Article, ArticleTypedDict
from .articlebyline import ArticleByline
from .articlecreate import (
    ArticleCreate,
    ArticleCreateArticleByline,
    ArticleCreateArticleVisibility,
    ArticleCreateTypedDict,
)
from .articlepreview import ArticlePreview, ArticlePreviewTypedDict
from .articlereceivers import ArticleReceivers, ArticleReceiversTypedDict
from .articles_deleteop import ArticlesDeleteRequest, ArticlesDeleteRequestTypedDict
from .articles_getop import ArticlesGetRequest, ArticlesGetRequestTypedDict
from .articles_listop import (
    ArticleVisibilityFilter,
    ArticleVisibilityFilterTypedDict,
    ArticlesListQueryParamOrganizationIDFilter,
    ArticlesListQueryParamOrganizationIDFilterTypedDict,
    ArticlesListRequest,
    ArticlesListRequestTypedDict,
    ArticlesListResponse,
    ArticlesListResponseTypedDict,
)
from .articles_previewop import ArticlesPreviewRequest, ArticlesPreviewRequestTypedDict
from .articles_receiversop import (
    ArticlesReceiversRequest,
    ArticlesReceiversRequestTypedDict,
)
from .articles_sendop import ArticlesSendRequest, ArticlesSendRequestTypedDict
from .articles_updateop import ArticlesUpdateRequest, ArticlesUpdateRequestTypedDict
from .articleupdate import ArticleUpdate, ArticleUpdateTypedDict
from .articlevisibility import ArticleVisibility
from .assignee import Assignee, AssigneeTypedDict
from .author import Author, AuthorTypedDict
from .benefitads import BenefitAds, BenefitAdsType, BenefitAdsTypedDict
from .benefitadscreate import (
    BenefitAdsCreate,
    BenefitAdsCreateType,
    BenefitAdsCreateTypedDict,
)
from .benefitadsproperties import BenefitAdsProperties, BenefitAdsPropertiesTypedDict
from .benefitadssubscriber import (
    BenefitAdsSubscriber,
    BenefitAdsSubscriberType,
    BenefitAdsSubscriberTypedDict,
)
from .benefitadsupdate import (
    BenefitAdsUpdate,
    BenefitAdsUpdateType,
    BenefitAdsUpdateTypedDict,
)
from .benefitarticles import (
    BenefitArticles,
    BenefitArticlesType,
    BenefitArticlesTypedDict,
)
from .benefitarticlesproperties import (
    BenefitArticlesProperties,
    BenefitArticlesPropertiesTypedDict,
)
from .benefitarticlessubscriber import (
    BenefitArticlesSubscriber,
    BenefitArticlesSubscriberTypedDict,
    Type,
)
from .benefitarticlessubscriberproperties import (
    BenefitArticlesSubscriberProperties,
    BenefitArticlesSubscriberPropertiesTypedDict,
)
from .benefitarticlesupdate import (
    BenefitArticlesUpdate,
    BenefitArticlesUpdateType,
    BenefitArticlesUpdateTypedDict,
)
from .benefitbase import BenefitBase, BenefitBaseTypedDict
from .benefitcustom import BenefitCustom, BenefitCustomType, BenefitCustomTypedDict
from .benefitcustomcreate import (
    BenefitCustomCreate,
    BenefitCustomCreateType,
    BenefitCustomCreateTypedDict,
)
from .benefitcustomproperties import (
    BenefitCustomProperties,
    BenefitCustomPropertiesTypedDict,
)
from .benefitcustomsubscriber import (
    BenefitCustomSubscriber,
    BenefitCustomSubscriberType,
    BenefitCustomSubscriberTypedDict,
)
from .benefitcustomsubscriberproperties import (
    BenefitCustomSubscriberProperties,
    BenefitCustomSubscriberPropertiesTypedDict,
)
from .benefitcustomupdate import (
    BenefitCustomUpdate,
    BenefitCustomUpdateType,
    BenefitCustomUpdateTypedDict,
)
from .benefitdiscord_input import (
    BenefitDiscordInput,
    BenefitDiscordInputType,
    BenefitDiscordInputTypedDict,
)
from .benefitdiscord_output import (
    BenefitDiscordOutput,
    BenefitDiscordOutputType,
    BenefitDiscordOutputTypedDict,
)
from .benefitdiscordcreate import (
    BenefitDiscordCreate,
    BenefitDiscordCreateType,
    BenefitDiscordCreateTypedDict,
)
from .benefitdiscordcreateproperties import (
    BenefitDiscordCreateProperties,
    BenefitDiscordCreatePropertiesTypedDict,
)
from .benefitdiscordproperties_input import (
    BenefitDiscordPropertiesInput,
    BenefitDiscordPropertiesInputTypedDict,
)
from .benefitdiscordproperties_output import (
    BenefitDiscordPropertiesOutput,
    BenefitDiscordPropertiesOutputTypedDict,
)
from .benefitdiscordsubscriber import (
    BenefitDiscordSubscriber,
    BenefitDiscordSubscriberType,
    BenefitDiscordSubscriberTypedDict,
)
from .benefitdiscordsubscriberproperties import (
    BenefitDiscordSubscriberProperties,
    BenefitDiscordSubscriberPropertiesTypedDict,
)
from .benefitdiscordupdate import (
    BenefitDiscordUpdate,
    BenefitDiscordUpdateType,
    BenefitDiscordUpdateTypedDict,
)
from .benefitdownloadables import (
    BenefitDownloadables,
    BenefitDownloadablesType,
    BenefitDownloadablesTypedDict,
)
from .benefitdownloadablescreate import (
    BenefitDownloadablesCreate,
    BenefitDownloadablesCreateType,
    BenefitDownloadablesCreateTypedDict,
)
from .benefitdownloadablescreateproperties import (
    BenefitDownloadablesCreateProperties,
    BenefitDownloadablesCreatePropertiesTypedDict,
)
from .benefitdownloadablesproperties import (
    BenefitDownloadablesProperties,
    BenefitDownloadablesPropertiesTypedDict,
)
from .benefitdownloadablessubscriber import (
    BenefitDownloadablesSubscriber,
    BenefitDownloadablesSubscriberType,
    BenefitDownloadablesSubscriberTypedDict,
)
from .benefitdownloadablessubscriberproperties import (
    BenefitDownloadablesSubscriberProperties,
    BenefitDownloadablesSubscriberPropertiesTypedDict,
)
from .benefitdownloadablesupdate import (
    BenefitDownloadablesUpdate,
    BenefitDownloadablesUpdateType,
    BenefitDownloadablesUpdateTypedDict,
)
from .benefitgithubrepository import (
    BenefitGitHubRepository,
    BenefitGitHubRepositoryType,
    BenefitGitHubRepositoryTypedDict,
)
from .benefitgithubrepositorycreate import (
    BenefitGitHubRepositoryCreate,
    BenefitGitHubRepositoryCreateType,
    BenefitGitHubRepositoryCreateTypedDict,
)
from .benefitgithubrepositorycreateproperties import (
    BenefitGitHubRepositoryCreateProperties,
    BenefitGitHubRepositoryCreatePropertiesPermission,
    BenefitGitHubRepositoryCreatePropertiesTypedDict,
)
from .benefitgithubrepositoryproperties import (
    BenefitGitHubRepositoryProperties,
    BenefitGitHubRepositoryPropertiesTypedDict,
    Permission,
)
from .benefitgithubrepositorysubscriber import (
    BenefitGitHubRepositorySubscriber,
    BenefitGitHubRepositorySubscriberType,
    BenefitGitHubRepositorySubscriberTypedDict,
)
from .benefitgithubrepositorysubscriberproperties import (
    BenefitGitHubRepositorySubscriberProperties,
    BenefitGitHubRepositorySubscriberPropertiesTypedDict,
)
from .benefitgithubrepositoryupdate import (
    BenefitGitHubRepositoryUpdate,
    BenefitGitHubRepositoryUpdateType,
    BenefitGitHubRepositoryUpdateTypedDict,
)
from .benefitgrant import BenefitGrant, BenefitGrantTypedDict
from .benefitgrantads import BenefitGrantAds, BenefitGrantAdsTypedDict
from .benefitgrantadsproperties import (
    BenefitGrantAdsProperties,
    BenefitGrantAdsPropertiesTypedDict,
)
from .benefitgrantlicensekeys import (
    BenefitGrantLicenseKeys,
    BenefitGrantLicenseKeysTypedDict,
)
from .benefitgrantlicensekeysproperties import (
    BenefitGrantLicenseKeysProperties,
    BenefitGrantLicenseKeysPropertiesTypedDict,
)
from .benefitgrantproperties import (
    BenefitGrantProperties,
    BenefitGrantPropertiesTypedDict,
)
from .benefitlicensekeyactivationproperties import (
    BenefitLicenseKeyActivationProperties,
    BenefitLicenseKeyActivationPropertiesTypedDict,
)
from .benefitlicensekeyexpirationproperties import (
    BenefitLicenseKeyExpirationProperties,
    BenefitLicenseKeyExpirationPropertiesTypedDict,
    Timeframe,
)
from .benefitlicensekeys_input import (
    BenefitLicenseKeysInput,
    BenefitLicenseKeysInputType,
    BenefitLicenseKeysInputTypedDict,
)
from .benefitlicensekeys_output import (
    BenefitLicenseKeysOutput,
    BenefitLicenseKeysOutputType,
    BenefitLicenseKeysOutputTypedDict,
)
from .benefitlicensekeyscreate import (
    BenefitLicenseKeysCreate,
    BenefitLicenseKeysCreateType,
    BenefitLicenseKeysCreateTypedDict,
)
from .benefitlicensekeyscreateproperties import (
    BenefitLicenseKeysCreateProperties,
    BenefitLicenseKeysCreatePropertiesTypedDict,
)
from .benefitlicensekeysproperties import (
    BenefitLicenseKeysProperties,
    BenefitLicenseKeysPropertiesTypedDict,
)
from .benefitlicensekeyssubscriber import (
    BenefitLicenseKeysSubscriber,
    BenefitLicenseKeysSubscriberType,
    BenefitLicenseKeysSubscriberTypedDict,
)
from .benefitlicensekeyssubscriberproperties import (
    BenefitLicenseKeysSubscriberProperties,
    BenefitLicenseKeysSubscriberPropertiesTypedDict,
)
from .benefitlicensekeysupdate import (
    BenefitLicenseKeysUpdate,
    BenefitLicenseKeysUpdateType,
    BenefitLicenseKeysUpdateTypedDict,
)
from .benefits_createop import (
    BenefitsCreateBenefitCreate,
    BenefitsCreateBenefitCreateTypedDict,
    BenefitsCreateResponseBenefitsCreate,
    BenefitsCreateResponseBenefitsCreateTypedDict,
)
from .benefits_deleteop import BenefitsDeleteRequest, BenefitsDeleteRequestTypedDict
from .benefits_getop import (
    BenefitsGetRequest,
    BenefitsGetRequestTypedDict,
    BenefitsGetResponseBenefitsGet,
    BenefitsGetResponseBenefitsGetTypedDict,
)
from .benefits_grantsop import (
    BenefitsGrantsRequest,
    BenefitsGrantsRequestTypedDict,
    BenefitsGrantsResponse,
    BenefitsGrantsResponseTypedDict,
)
from .benefits_listop import (
    BenefitsListQueryParamOrganizationIDFilter,
    BenefitsListQueryParamOrganizationIDFilterTypedDict,
    BenefitsListRequest,
    BenefitsListRequestTypedDict,
    BenefitsListResponse,
    BenefitsListResponseTypedDict,
    QueryParamBenefitTypeFilter,
    QueryParamBenefitTypeFilterTypedDict,
)
from .benefits_updateop import (
    BenefitsUpdateBenefitUpdate,
    BenefitsUpdateBenefitUpdateTypedDict,
    BenefitsUpdateRequest,
    BenefitsUpdateRequestTypedDict,
    BenefitsUpdateResponseBenefitsUpdate,
    BenefitsUpdateResponseBenefitsUpdateTypedDict,
)
from .benefittype import BenefitType
from .bylineprofile import BylineProfile, BylineProfileTypedDict
from .checkout import Checkout, CheckoutTypedDict
from .checkoutcreate import CheckoutCreate, CheckoutCreateTypedDict
from .checkouts_getop import CheckoutsGetRequest, CheckoutsGetRequestTypedDict
from .currencyamount import CurrencyAmount, CurrencyAmountTypedDict
from .donation_input import DonationInput, DonationInputTypedDict, Donor, DonorTypedDict
from .donationorganization import DonationOrganization, DonationOrganizationTypedDict
from .donationuser import DonationUser, DonationUserTypedDict
from .downloadablefilecreate import (
    DownloadableFileCreate,
    DownloadableFileCreateService,
    DownloadableFileCreateTypedDict,
)
from .downloadablefileread import (
    DownloadableFileRead,
    DownloadableFileReadService,
    DownloadableFileReadTypedDict,
)
from .downloadableread import DownloadableRead, DownloadableReadTypedDict
from .existingproductprice import ExistingProductPrice, ExistingProductPriceTypedDict
from .external_organizations_listop import (
    ExternalOrganizationsListQueryParamOrganizationIDFilter,
    ExternalOrganizationsListQueryParamOrganizationIDFilterTypedDict,
    ExternalOrganizationsListRequest,
    ExternalOrganizationsListRequestTypedDict,
    ExternalOrganizationsListResponse,
    ExternalOrganizationsListResponseTypedDict,
    PlatformFilter,
    PlatformFilterTypedDict,
    RepositoryNameFilter,
    RepositoryNameFilterTypedDict,
)
from .externalorganization import ExternalOrganization, ExternalOrganizationTypedDict
from .externalorganizationsortproperty import ExternalOrganizationSortProperty
from .filedownload import FileDownload, FileDownloadTypedDict
from .filenotfound import FileNotFound, FileNotFoundData, FileNotFoundType
from .filepatch import FilePatch, FilePatchTypedDict
from .files_createop import FilesCreateFileCreate, FilesCreateFileCreateTypedDict
from .files_deleteop import FilesDeleteRequest, FilesDeleteRequestTypedDict
from .files_listop import (
    FilesListRequest,
    FilesListRequestTypedDict,
    FilesListResponse,
    FilesListResponseTypedDict,
)
from .files_updateop import (
    FilesUpdateRequest,
    FilesUpdateRequestTypedDict,
    FilesUpdateResponseFilesUpdate,
    FilesUpdateResponseFilesUpdateTypedDict,
)
from .files_uploadedop import (
    FilesUploadedRequest,
    FilesUploadedRequestTypedDict,
    FilesUploadedResponseFilesUploaded,
    FilesUploadedResponseFilesUploadedTypedDict,
)
from .fileservicetypes import FileServiceTypes
from .fileupload import FileUpload, FileUploadTypedDict
from .fileuploadcompleted import FileUploadCompleted, FileUploadCompletedTypedDict
from .funding import Funding, FundingTypedDict
from .httpvalidationerror import HTTPValidationError, HTTPValidationErrorData
from .introspecttokenresponse import (
    IntrospectTokenResponse,
    IntrospectTokenResponseTokenType,
    IntrospectTokenResponseTypedDict,
)
from .issue_input import IssueInput, IssueInputTypedDict
from .label import Label, LabelTypedDict
from .license_keys_get_activationop import (
    LicenseKeysGetActivationRequest,
    LicenseKeysGetActivationRequestTypedDict,
)
from .license_keys_getop import LicenseKeysGetRequest, LicenseKeysGetRequestTypedDict
from .license_keys_listop import (
    LicenseKeysListQueryParamOrganizationIDFilter,
    LicenseKeysListQueryParamOrganizationIDFilterTypedDict,
    LicenseKeysListRequest,
    LicenseKeysListRequestTypedDict,
    LicenseKeysListResponse,
    LicenseKeysListResponseTypedDict,
)
from .license_keys_updateop import (
    LicenseKeysUpdateRequest,
    LicenseKeysUpdateRequestTypedDict,
)
from .licensekeyactivate import (
    LicenseKeyActivate,
    LicenseKeyActivateConditions,
    LicenseKeyActivateConditionsTypedDict,
    LicenseKeyActivateMeta,
    LicenseKeyActivateMetaTypedDict,
    LicenseKeyActivateTypedDict,
)
from .licensekeyactivationbase import (
    LicenseKeyActivationBase,
    LicenseKeyActivationBaseTypedDict,
    Meta,
    MetaTypedDict,
)
from .licensekeyactivationread import (
    LicenseKeyActivationRead,
    LicenseKeyActivationReadMeta,
    LicenseKeyActivationReadMetaTypedDict,
    LicenseKeyActivationReadTypedDict,
)
from .licensekeydeactivate import LicenseKeyDeactivate, LicenseKeyDeactivateTypedDict
from .licensekeyread import LicenseKeyRead, LicenseKeyReadTypedDict
from .licensekeystatus import LicenseKeyStatus
from .licensekeyupdate import LicenseKeyUpdate, LicenseKeyUpdateTypedDict
from .licensekeyvalidate import (
    Conditions,
    ConditionsTypedDict,
    LicenseKeyValidate,
    LicenseKeyValidateTypedDict,
)
from .licensekeywithactivations import (
    LicenseKeyWithActivations,
    LicenseKeyWithActivationsTypedDict,
)
from .listresource_article_ import ListResourceArticle, ListResourceArticleTypedDict
from .listresource_benefit_ import (
    Benefit,
    BenefitTypedDict,
    ListResourceBenefit,
    ListResourceBenefitTypedDict,
)
from .listresource_benefitgrant_ import (
    ListResourceBenefitGrant,
    ListResourceBenefitGrantTypedDict,
)
from .listresource_downloadableread_ import (
    ListResourceDownloadableRead,
    ListResourceDownloadableReadTypedDict,
)
from .listresource_externalorganization_ import (
    ListResourceExternalOrganization,
    ListResourceExternalOrganizationTypedDict,
)
from .listresource_fileread_ import (
    FileRead,
    FileReadTypedDict,
    ListResourceFileRead,
    ListResourceFileReadTypedDict,
)
from .listresource_licensekeyread_ import (
    ListResourceLicenseKeyRead,
    ListResourceLicenseKeyReadTypedDict,
)
from .listresource_oauth2client_ import (
    ListResourceOAuth2Client,
    ListResourceOAuth2ClientTypedDict,
)
from .listresource_order_ import ListResourceOrder, ListResourceOrderTypedDict
from .listresource_organization_ import (
    ListResourceOrganization,
    ListResourceOrganizationTypedDict,
)
from .listresource_product_ import ListResourceProduct, ListResourceProductTypedDict
from .listresource_repository_ import (
    ListResourceRepository,
    ListResourceRepositoryTypedDict,
)
from .listresource_subscription_ import (
    ListResourceSubscription,
    ListResourceSubscriptionTypedDict,
)
from .listresource_useradvertisementcampaign_ import (
    ListResourceUserAdvertisementCampaign,
    ListResourceUserAdvertisementCampaignTypedDict,
)
from .listresource_userbenefit_ import (
    ListResourceUserBenefit,
    ListResourceUserBenefitTypedDict,
    UserBenefit,
    UserBenefitTypedDict,
)
from .listresource_userorder_ import (
    ListResourceUserOrder,
    ListResourceUserOrderTypedDict,
)
from .listresource_usersubscription_ import (
    ListResourceUserSubscription,
    ListResourceUserSubscriptionTypedDict,
)
from .metric import Metric, MetricTypedDict
from .metricperiod import MetricPeriod, MetricPeriodTypedDict
from .metrics import Metrics, MetricsTypedDict
from .metrics_getop import (
    Interval,
    MetricsGetQueryParamOrganizationIDFilter,
    MetricsGetQueryParamOrganizationIDFilterTypedDict,
    MetricsGetQueryParamProductIDFilter,
    MetricsGetQueryParamProductIDFilterTypedDict,
    MetricsGetQueryParamProductPriceTypeFilter,
    MetricsGetQueryParamProductPriceTypeFilterTypedDict,
    MetricsGetRequest,
    MetricsGetRequestTypedDict,
)
from .metricsintervallimit import MetricsIntervalLimit, MetricsIntervalLimitTypedDict
from .metricsintervalslimits import (
    MetricsIntervalsLimits,
    MetricsIntervalsLimitsTypedDict,
)
from .metricslimits import MetricsLimits, MetricsLimitsTypedDict
from .metricsresponse import MetricsResponse, MetricsResponseTypedDict
from .metrictype import MetricType
from .notpermitted import NotPermitted, NotPermittedData, NotPermittedType
from .oauth2_clients_listop import (
    Oauth2ClientsListRequest,
    Oauth2ClientsListRequestTypedDict,
    Oauth2ClientsListResponse,
    Oauth2ClientsListResponseTypedDict,
)
from .oauth2_clients_oauth2_delete_clientop import (
    Oauth2ClientsOauth2DeleteClientRequest,
    Oauth2ClientsOauth2DeleteClientRequestTypedDict,
)
from .oauth2_clients_oauth2_get_clientop import (
    Oauth2ClientsOauth2GetClientRequest,
    Oauth2ClientsOauth2GetClientRequestTypedDict,
)
from .oauth2_clients_oauth2_update_clientop import (
    Oauth2ClientsOauth2UpdateClientRequest,
    Oauth2ClientsOauth2UpdateClientRequestTypedDict,
)
from .oauth2_introspect_tokenop import (
    Oauth2IntrospectTokenIntrospectTokenRequest,
    Oauth2IntrospectTokenIntrospectTokenRequestTypedDict,
    Oauth2IntrospectTokenTokenTypeHint,
)
from .oauth2_request_tokenop import (
    Oauth2RequestTokenRequestBody,
    Oauth2RequestTokenRequestBodyTypedDict,
)
from .oauth2_revoke_tokenop import (
    Oauth2RevokeTokenRevokeTokenRequest,
    Oauth2RevokeTokenRevokeTokenRequestTypedDict,
    TokenTypeHint,
)
from .oauth2_userinfoop import (
    Oauth2UserinfoResponseOauth2Userinfo,
    Oauth2UserinfoResponseOauth2UserinfoTypedDict,
)
from .oauth2client import (
    GrantTypes,
    OAuth2Client,
    OAuth2ClientTypedDict,
    ResponseTypes,
    TokenEndpointAuthMethod,
)
from .oauth2clientconfiguration import (
    OAuth2ClientConfiguration,
    OAuth2ClientConfigurationGrantTypes,
    OAuth2ClientConfigurationResponseTypes,
    OAuth2ClientConfigurationTokenEndpointAuthMethod,
    OAuth2ClientConfigurationTypedDict,
)
from .oauth2clientconfigurationupdate import (
    OAuth2ClientConfigurationUpdate,
    OAuth2ClientConfigurationUpdateGrantTypes,
    OAuth2ClientConfigurationUpdateResponseTypes,
    OAuth2ClientConfigurationUpdateTokenEndpointAuthMethod,
    OAuth2ClientConfigurationUpdateTypedDict,
)
from .onev1_1oauth2_1token_post_x_components_authorizationcodetokenrequest import (
    GrantType,
    Onev11oauth21tokenPostXComponentsAuthorizationCodeTokenRequest,
    Onev11oauth21tokenPostXComponentsAuthorizationCodeTokenRequestTypedDict,
)
from .onev1_1oauth2_1token_post_x_components_refreshtokenrequest import (
    Onev11oauth21tokenPostXComponentsRefreshTokenRequest,
    Onev11oauth21tokenPostXComponentsRefreshTokenRequestGrantType,
    Onev11oauth21tokenPostXComponentsRefreshTokenRequestTypedDict,
)
from .order_input import OrderInput, OrderInputTypedDict
from .order_output import OrderOutput, OrderOutputTypedDict
from .orderinvoice import OrderInvoice, OrderInvoiceTypedDict
from .orderproduct import OrderProduct, OrderProductTypedDict
from .orders_getop import OrdersGetRequest, OrdersGetRequestTypedDict
from .orders_invoiceop import OrdersInvoiceRequest, OrdersInvoiceRequestTypedDict
from .orders_listop import (
    OrdersListQueryParamOrganizationIDFilter,
    OrdersListQueryParamOrganizationIDFilterTypedDict,
    OrdersListQueryParamProductIDFilter,
    OrdersListQueryParamProductIDFilterTypedDict,
    OrdersListRequest,
    OrdersListRequestTypedDict,
    OrdersListResponse,
    OrdersListResponseTypedDict,
    QueryParamProductPriceTypeFilter,
    QueryParamProductPriceTypeFilterTypedDict,
    UserIDFilter,
    UserIDFilterTypedDict,
)
from .ordersortproperty import OrderSortProperty
from .ordersubscription import OrderSubscription, OrderSubscriptionTypedDict
from .orderuser import OrderUser, OrderUserTypedDict
from .organization_input import OrganizationInput, OrganizationInputTypedDict
from .organization_output import OrganizationOutput, OrganizationOutputTypedDict
from .organizationavatarfilecreate import (
    OrganizationAvatarFileCreate,
    OrganizationAvatarFileCreateService,
    OrganizationAvatarFileCreateTypedDict,
)
from .organizationavatarfileread import (
    OrganizationAvatarFileRead,
    OrganizationAvatarFileReadService,
    OrganizationAvatarFileReadTypedDict,
)
from .organizationcreate import OrganizationCreate, OrganizationCreateTypedDict
from .organizationfeaturesettings import (
    OrganizationFeatureSettings,
    OrganizationFeatureSettingsTypedDict,
)
from .organizationprofilesettings import (
    OrganizationProfileSettings,
    OrganizationProfileSettingsTypedDict,
)
from .organizations_getop import (
    OrganizationsGetRequest,
    OrganizationsGetRequestTypedDict,
)
from .organizations_listop import (
    OrganizationsListRequest,
    OrganizationsListRequestTypedDict,
    OrganizationsListResponse,
    OrganizationsListResponseTypedDict,
)
from .organizations_updateop import (
    OrganizationsUpdateRequest,
    OrganizationsUpdateRequestTypedDict,
)
from .organizationsortproperty import OrganizationSortProperty
from .organizationsubscribepromotesettings import (
    OrganizationSubscribePromoteSettings,
    OrganizationSubscribePromoteSettingsTypedDict,
)
from .organizationupdate import OrganizationUpdate, OrganizationUpdateTypedDict
from .pagination import Pagination, PaginationTypedDict
from .platforms import Platforms
from .pledge_input import PledgeInput, PledgeInputTypedDict
from .pledger import Pledger, PledgerTypedDict
from .pledgestate import PledgeState
from .pledgetype import PledgeType
from .product_input import (
    ProductInput,
    ProductInputBenefits,
    ProductInputBenefitsTypedDict,
    ProductInputTypedDict,
)
from .product_output import (
    ProductOutput,
    ProductOutputBenefits,
    ProductOutputBenefitsTypedDict,
    ProductOutputTypedDict,
)
from .productbenefitsupdate import ProductBenefitsUpdate, ProductBenefitsUpdateTypedDict
from .productmediafilecreate import (
    ProductMediaFileCreate,
    ProductMediaFileCreateService,
    ProductMediaFileCreateTypedDict,
)
from .productmediafileread_input import (
    ProductMediaFileReadInput,
    ProductMediaFileReadInputService,
    ProductMediaFileReadInputTypedDict,
)
from .productmediafileread_output import (
    ProductMediaFileReadOutput,
    ProductMediaFileReadOutputTypedDict,
    Service,
)
from .productonetimecreate import (
    Prices,
    PricesTypedDict,
    ProductOneTimeCreate,
    ProductOneTimeCreateTypedDict,
)
from .productprice_input import ProductPriceInput, ProductPriceInputTypedDict
from .productprice_output import ProductPriceOutput, ProductPriceOutputTypedDict
from .productpriceonetime import ProductPriceOneTime, ProductPriceOneTimeTypedDict
from .productpriceonetimecustom import (
    ProductPriceOneTimeCustom,
    ProductPriceOneTimeCustomAmountType,
    ProductPriceOneTimeCustomType,
    ProductPriceOneTimeCustomTypedDict,
)
from .productpriceonetimecustomcreate import (
    ProductPriceOneTimeCustomCreate,
    ProductPriceOneTimeCustomCreateAmountType,
    ProductPriceOneTimeCustomCreateType,
    ProductPriceOneTimeCustomCreateTypedDict,
)
from .productpriceonetimefixed import (
    ProductPriceOneTimeFixed,
    ProductPriceOneTimeFixedAmountType,
    ProductPriceOneTimeFixedType,
    ProductPriceOneTimeFixedTypedDict,
)
from .productpriceonetimefixedcreate import (
    ProductPriceOneTimeFixedCreate,
    ProductPriceOneTimeFixedCreateAmountType,
    ProductPriceOneTimeFixedCreateType,
    ProductPriceOneTimeFixedCreateTypedDict,
)
from .productpriceonetimefree import (
    ProductPriceOneTimeFree,
    ProductPriceOneTimeFreeAmountType,
    ProductPriceOneTimeFreeType,
    ProductPriceOneTimeFreeTypedDict,
)
from .productpriceonetimefreecreate import (
    ProductPriceOneTimeFreeCreate,
    ProductPriceOneTimeFreeCreateAmountType,
    ProductPriceOneTimeFreeCreateType,
    ProductPriceOneTimeFreeCreateTypedDict,
)
from .productpricerecurring_input import (
    ProductPriceRecurringInput,
    ProductPriceRecurringInputTypedDict,
)
from .productpricerecurring_output import (
    ProductPriceRecurringOutput,
    ProductPriceRecurringOutputTypedDict,
)
from .productpricerecurringcustom import (
    ProductPriceRecurringCustom,
    ProductPriceRecurringCustomAmountType,
    ProductPriceRecurringCustomType,
    ProductPriceRecurringCustomTypedDict,
)
from .productpricerecurringfixed import (
    AmountType,
    ProductPriceRecurringFixed,
    ProductPriceRecurringFixedType,
    ProductPriceRecurringFixedTypedDict,
)
from .productpricerecurringfixedcreate import (
    ProductPriceRecurringFixedCreate,
    ProductPriceRecurringFixedCreateAmountType,
    ProductPriceRecurringFixedCreateType,
    ProductPriceRecurringFixedCreateTypedDict,
)
from .productpricerecurringfree import (
    ProductPriceRecurringFree,
    ProductPriceRecurringFreeAmountType,
    ProductPriceRecurringFreeType,
    ProductPriceRecurringFreeTypedDict,
)
from .productpricerecurringfreecreate import (
    ProductPriceRecurringFreeCreate,
    ProductPriceRecurringFreeCreateAmountType,
    ProductPriceRecurringFreeCreateType,
    ProductPriceRecurringFreeCreateTypedDict,
)
from .productpricetype import ProductPriceType
from .productrecurringcreate import (
    ProductRecurringCreate,
    ProductRecurringCreatePrices,
    ProductRecurringCreatePricesTypedDict,
    ProductRecurringCreateTypedDict,
)
from .products_createop import (
    ProductsCreateProductCreate,
    ProductsCreateProductCreateTypedDict,
)
from .products_getop import ProductsGetRequest, ProductsGetRequestTypedDict
from .products_listop import (
    ProductsListQueryParamOrganizationIDFilter,
    ProductsListQueryParamOrganizationIDFilterTypedDict,
    ProductsListRequest,
    ProductsListRequestTypedDict,
    ProductsListResponse,
    ProductsListResponseTypedDict,
    QueryParamBenefitIDFilter,
    QueryParamBenefitIDFilterTypedDict,
)
from .products_update_benefitsop import (
    ProductsUpdateBenefitsRequest,
    ProductsUpdateBenefitsRequestTypedDict,
)
from .products_updateop import ProductsUpdateRequest, ProductsUpdateRequestTypedDict
from .productupdate import (
    ProductUpdate,
    ProductUpdatePrices,
    ProductUpdatePricesTypedDict,
    ProductUpdateTypedDict,
)
from .reactions import Reactions, ReactionsTypedDict
from .repositories_getop import RepositoriesGetRequest, RepositoriesGetRequestTypedDict
from .repositories_listop import (
    ExternalOrganizationNameFilter,
    ExternalOrganizationNameFilterTypedDict,
    QueryParamPlatformFilter,
    QueryParamPlatformFilterTypedDict,
    QueryParamRepositoryNameFilter,
    QueryParamRepositoryNameFilterTypedDict,
    RepositoriesListQueryParamOrganizationIDFilter,
    RepositoriesListQueryParamOrganizationIDFilterTypedDict,
    RepositoriesListRequest,
    RepositoriesListRequestTypedDict,
    RepositoriesListResponse,
    RepositoriesListResponseTypedDict,
)
from .repositories_updateop import (
    RepositoriesUpdateRequest,
    RepositoriesUpdateRequestTypedDict,
)
from .repository_input import RepositoryInput, RepositoryInputTypedDict
from .repository_output import RepositoryOutput, RepositoryOutputTypedDict
from .repositoryprofilesettings import (
    RepositoryProfileSettings,
    RepositoryProfileSettingsTypedDict,
)
from .repositoryprofilesettingsupdate import (
    RepositoryProfileSettingsUpdate,
    RepositoryProfileSettingsUpdateTypedDict,
)
from .repositorysortproperty import RepositorySortProperty
from .repositoryupdate import RepositoryUpdate, RepositoryUpdateTypedDict
from .resourcenotfound import (
    ResourceNotFound,
    ResourceNotFoundData,
    ResourceNotFoundType,
)
from .revoketokenresponse import RevokeTokenResponse, RevokeTokenResponseTypedDict
from .s3downloadurl import S3DownloadURL, S3DownloadURLTypedDict
from .s3filecreatemultipart import S3FileCreateMultipart, S3FileCreateMultipartTypedDict
from .s3filecreatepart import S3FileCreatePart, S3FileCreatePartTypedDict
from .s3fileuploadcompletedpart import (
    S3FileUploadCompletedPart,
    S3FileUploadCompletedPartTypedDict,
)
from .s3fileuploadmultipart import S3FileUploadMultipart, S3FileUploadMultipartTypedDict
from .s3fileuploadpart import S3FileUploadPart, S3FileUploadPartTypedDict
from .sdkerror import SDKError
from .security import Security, SecurityTypedDict
from .state import State
from .subscription_input import SubscriptionInput, SubscriptionInputTypedDict
from .subscription_output import SubscriptionOutput, SubscriptionOutputTypedDict
from .subscriptionrecurringinterval import SubscriptionRecurringInterval
from .subscriptions_exportop import (
    OrganizationID,
    OrganizationIDTypedDict,
    SubscriptionsExportRequest,
    SubscriptionsExportRequestTypedDict,
)
from .subscriptions_listop import (
    SubscriptionsListQueryParamOrganizationIDFilter,
    SubscriptionsListQueryParamOrganizationIDFilterTypedDict,
    SubscriptionsListQueryParamProductIDFilter,
    SubscriptionsListQueryParamProductIDFilterTypedDict,
    SubscriptionsListRequest,
    SubscriptionsListRequestTypedDict,
    SubscriptionsListResponse,
    SubscriptionsListResponseTypedDict,
)
from .subscriptionsortproperty import SubscriptionSortProperty
from .subscriptionstatus import SubscriptionStatus
from .subscriptionuser import SubscriptionUser, SubscriptionUserTypedDict
from .subtype import SubType
from .tokenresponse import TokenResponse, TokenResponseTypedDict, TokenType
from .unauthorized import Unauthorized, UnauthorizedData, UnauthorizedType
from .useradvertisementcampaign import (
    UserAdvertisementCampaign,
    UserAdvertisementCampaignTypedDict,
)
from .useradvertisementcampaigncreate import (
    UserAdvertisementCampaignCreate,
    UserAdvertisementCampaignCreateTypedDict,
)
from .useradvertisementcampaignenable import (
    UserAdvertisementCampaignEnable,
    UserAdvertisementCampaignEnableTypedDict,
)
from .useradvertisementcampaignupdate import (
    UserAdvertisementCampaignUpdate,
    UserAdvertisementCampaignUpdateTypedDict,
)
from .useradvertisementsortproperty import UserAdvertisementSortProperty
from .userbenefitsortproperty import UserBenefitSortProperty
from .userinfoorganization import UserInfoOrganization, UserInfoOrganizationTypedDict
from .userinfouser import UserInfoUser, UserInfoUserTypedDict
from .userorder import UserOrder, UserOrderTypedDict
from .userorderinvoice import UserOrderInvoice, UserOrderInvoiceTypedDict
from .userorderproduct import (
    BenefitsModel,
    BenefitsModelTypedDict,
    UserOrderProduct,
    UserOrderProductTypedDict,
)
from .userordersortproperty import UserOrderSortProperty
from .userordersubscription import UserOrderSubscription, UserOrderSubscriptionTypedDict
from .users_advertisements_deleteop import (
    UsersAdvertisementsDeleteRequest,
    UsersAdvertisementsDeleteRequestTypedDict,
)
from .users_advertisements_enableop import (
    UsersAdvertisementsEnableRequest,
    UsersAdvertisementsEnableRequestTypedDict,
)
from .users_advertisements_getop import (
    UsersAdvertisementsGetRequest,
    UsersAdvertisementsGetRequestTypedDict,
)
from .users_advertisements_listop import (
    UsersAdvertisementsListRequest,
    UsersAdvertisementsListRequestTypedDict,
    UsersAdvertisementsListResponse,
    UsersAdvertisementsListResponseTypedDict,
)
from .users_advertisements_updateop import (
    UsersAdvertisementsUpdateRequest,
    UsersAdvertisementsUpdateRequestTypedDict,
)
from .users_benefits_getop import (
    UsersBenefitsGetRequest,
    UsersBenefitsGetRequestTypedDict,
    UsersBenefitsGetResponseUsersBenefitsGet,
    UsersBenefitsGetResponseUsersBenefitsGetTypedDict,
)
from .users_benefits_listop import (
    BenefitTypeFilter,
    BenefitTypeFilterTypedDict,
    OrderIDFilter,
    OrderIDFilterTypedDict,
    OrganizationIDFilter,
    OrganizationIDFilterTypedDict,
    SubscriptionIDFilter,
    SubscriptionIDFilterTypedDict,
    UsersBenefitsListRequest,
    UsersBenefitsListRequestTypedDict,
    UsersBenefitsListResponse,
    UsersBenefitsListResponseTypedDict,
)
from .users_downloadables_getop import (
    UsersDownloadablesGetRequest,
    UsersDownloadablesGetRequestTypedDict,
)
from .users_downloadables_listop import (
    BenefitIDFilter,
    BenefitIDFilterTypedDict,
    UsersDownloadablesListQueryParamOrganizationIDFilter,
    UsersDownloadablesListQueryParamOrganizationIDFilterTypedDict,
    UsersDownloadablesListRequest,
    UsersDownloadablesListRequestTypedDict,
    UsersDownloadablesListResponse,
    UsersDownloadablesListResponseTypedDict,
)
from .users_license_keys_getop import (
    UsersLicenseKeysGetRequest,
    UsersLicenseKeysGetRequestTypedDict,
)
from .users_license_keys_listop import (
    UsersLicenseKeysListQueryParamOrganizationIDFilter,
    UsersLicenseKeysListQueryParamOrganizationIDFilterTypedDict,
    UsersLicenseKeysListRequest,
    UsersLicenseKeysListRequestTypedDict,
    UsersLicenseKeysListResponse,
    UsersLicenseKeysListResponseTypedDict,
)
from .users_orders_getop import UsersOrdersGetRequest, UsersOrdersGetRequestTypedDict
from .users_orders_invoiceop import (
    UsersOrdersInvoiceRequest,
    UsersOrdersInvoiceRequestTypedDict,
)
from .users_orders_listop import (
    ProductIDFilter,
    ProductIDFilterTypedDict,
    ProductPriceTypeFilter,
    ProductPriceTypeFilterTypedDict,
    QueryParamOrganizationIDFilter,
    QueryParamOrganizationIDFilterTypedDict,
    QueryParamSubscriptionIDFilter,
    QueryParamSubscriptionIDFilterTypedDict,
    UsersOrdersListRequest,
    UsersOrdersListRequestTypedDict,
    UsersOrdersListResponse,
    UsersOrdersListResponseTypedDict,
)
from .users_subscriptions_cancelop import (
    UsersSubscriptionsCancelRequest,
    UsersSubscriptionsCancelRequestTypedDict,
)
from .users_subscriptions_getop import (
    UsersSubscriptionsGetRequest,
    UsersSubscriptionsGetRequestTypedDict,
)
from .users_subscriptions_listop import (
    QueryParamProductIDFilter,
    QueryParamProductIDFilterTypedDict,
    UsersSubscriptionsListQueryParamOrganizationIDFilter,
    UsersSubscriptionsListQueryParamOrganizationIDFilterTypedDict,
    UsersSubscriptionsListRequest,
    UsersSubscriptionsListRequestTypedDict,
    UsersSubscriptionsListResponse,
    UsersSubscriptionsListResponseTypedDict,
)
from .users_subscriptions_updateop import (
    UsersSubscriptionsUpdateRequest,
    UsersSubscriptionsUpdateRequestTypedDict,
)
from .usersubscription import UserSubscription, UserSubscriptionTypedDict
from .usersubscriptionproduct import (
    UserSubscriptionProduct,
    UserSubscriptionProductBenefits,
    UserSubscriptionProductBenefitsTypedDict,
    UserSubscriptionProductTypedDict,
)
from .usersubscriptionsortproperty import UserSubscriptionSortProperty
from .usersubscriptionupdate import (
    UserSubscriptionUpdate,
    UserSubscriptionUpdateTypedDict,
)
from .validatedlicensekey import ValidatedLicenseKey, ValidatedLicenseKeyTypedDict
from .validationerror import (
    Loc,
    LocTypedDict,
    ValidationError,
    ValidationErrorTypedDict,
)
from .webhookbenefitcreatedpayload import (
    WebhookBenefitCreatedPayload,
    WebhookBenefitCreatedPayloadBenefit,
    WebhookBenefitCreatedPayloadBenefitTypedDict,
    WebhookBenefitCreatedPayloadType,
    WebhookBenefitCreatedPayloadTypedDict,
)
from .webhookbenefitupdatedpayload import (
    WebhookBenefitUpdatedPayload,
    WebhookBenefitUpdatedPayloadBenefit,
    WebhookBenefitUpdatedPayloadBenefitTypedDict,
    WebhookBenefitUpdatedPayloadType,
    WebhookBenefitUpdatedPayloadTypedDict,
)
from .webhookdonationcreatedpayload import (
    WebhookDonationCreatedPayload,
    WebhookDonationCreatedPayloadType,
    WebhookDonationCreatedPayloadTypedDict,
)
from .webhookordercreatedpayload import (
    WebhookOrderCreatedPayload,
    WebhookOrderCreatedPayloadType,
    WebhookOrderCreatedPayloadTypedDict,
)
from .webhookorganizationupdatedpayload import (
    WebhookOrganizationUpdatedPayload,
    WebhookOrganizationUpdatedPayloadType,
    WebhookOrganizationUpdatedPayloadTypedDict,
)
from .webhookpledgecreatedpayload import (
    WebhookPledgeCreatedPayload,
    WebhookPledgeCreatedPayloadType,
    WebhookPledgeCreatedPayloadTypedDict,
)
from .webhookpledgeupdatedpayload import (
    WebhookPledgeUpdatedPayload,
    WebhookPledgeUpdatedPayloadType,
    WebhookPledgeUpdatedPayloadTypedDict,
)
from .webhookproductcreatedpayload import (
    WebhookProductCreatedPayload,
    WebhookProductCreatedPayloadType,
    WebhookProductCreatedPayloadTypedDict,
)
from .webhookproductupdatedpayload import (
    WebhookProductUpdatedPayload,
    WebhookProductUpdatedPayloadType,
    WebhookProductUpdatedPayloadTypedDict,
)
from .webhooksubscriptioncreatedpayload import (
    WebhookSubscriptionCreatedPayload,
    WebhookSubscriptionCreatedPayloadType,
    WebhookSubscriptionCreatedPayloadTypedDict,
)
from .webhooksubscriptionupdatedpayload import (
    WebhookSubscriptionUpdatedPayload,
    WebhookSubscriptionUpdatedPayloadType,
    WebhookSubscriptionUpdatedPayloadTypedDict,
)

__all__ = [
    "AdvertisementCampaign",
    "AdvertisementCampaignListResource",
    "AdvertisementCampaignListResourceTypedDict",
    "AdvertisementCampaignTypedDict",
    "AdvertisementSortProperty",
    "AdvertisementsGetRequest",
    "AdvertisementsGetRequestTypedDict",
    "AdvertisementsListRequest",
    "AdvertisementsListRequestTypedDict",
    "AdvertisementsListResponse",
    "AdvertisementsListResponseTypedDict",
    "AlreadyCanceledSubscription",
    "AlreadyCanceledSubscriptionData",
    "AlreadyCanceledSubscriptionType",
    "AmountType",
    "Article",
    "ArticleByline",
    "ArticleCreate",
    "ArticleCreateArticleByline",
    "ArticleCreateArticleVisibility",
    "ArticleCreateTypedDict",
    "ArticlePreview",
    "ArticlePreviewTypedDict",
    "ArticleReceivers",
    "ArticleReceiversTypedDict",
    "ArticleTypedDict",
    "ArticleUpdate",
    "ArticleUpdateTypedDict",
    "ArticleVisibility",
    "ArticleVisibilityFilter",
    "ArticleVisibilityFilterTypedDict",
    "ArticlesDeleteRequest",
    "ArticlesDeleteRequestTypedDict",
    "ArticlesGetRequest",
    "ArticlesGetRequestTypedDict",
    "ArticlesListQueryParamOrganizationIDFilter",
    "ArticlesListQueryParamOrganizationIDFilterTypedDict",
    "ArticlesListRequest",
    "ArticlesListRequestTypedDict",
    "ArticlesListResponse",
    "ArticlesListResponseTypedDict",
    "ArticlesPreviewRequest",
    "ArticlesPreviewRequestTypedDict",
    "ArticlesReceiversRequest",
    "ArticlesReceiversRequestTypedDict",
    "ArticlesSendRequest",
    "ArticlesSendRequestTypedDict",
    "ArticlesUpdateRequest",
    "ArticlesUpdateRequestTypedDict",
    "Assignee",
    "AssigneeTypedDict",
    "Author",
    "AuthorTypedDict",
    "Benefit",
    "BenefitAds",
    "BenefitAdsCreate",
    "BenefitAdsCreateType",
    "BenefitAdsCreateTypedDict",
    "BenefitAdsProperties",
    "BenefitAdsPropertiesTypedDict",
    "BenefitAdsSubscriber",
    "BenefitAdsSubscriberType",
    "BenefitAdsSubscriberTypedDict",
    "BenefitAdsType",
    "BenefitAdsTypedDict",
    "BenefitAdsUpdate",
    "BenefitAdsUpdateType",
    "BenefitAdsUpdateTypedDict",
    "BenefitArticles",
    "BenefitArticlesProperties",
    "BenefitArticlesPropertiesTypedDict",
    "BenefitArticlesSubscriber",
    "BenefitArticlesSubscriberProperties",
    "BenefitArticlesSubscriberPropertiesTypedDict",
    "BenefitArticlesSubscriberTypedDict",
    "BenefitArticlesType",
    "BenefitArticlesTypedDict",
    "BenefitArticlesUpdate",
    "BenefitArticlesUpdateType",
    "BenefitArticlesUpdateTypedDict",
    "BenefitBase",
    "BenefitBaseTypedDict",
    "BenefitCustom",
    "BenefitCustomCreate",
    "BenefitCustomCreateType",
    "BenefitCustomCreateTypedDict",
    "BenefitCustomProperties",
    "BenefitCustomPropertiesTypedDict",
    "BenefitCustomSubscriber",
    "BenefitCustomSubscriberProperties",
    "BenefitCustomSubscriberPropertiesTypedDict",
    "BenefitCustomSubscriberType",
    "BenefitCustomSubscriberTypedDict",
    "BenefitCustomType",
    "BenefitCustomTypedDict",
    "BenefitCustomUpdate",
    "BenefitCustomUpdateType",
    "BenefitCustomUpdateTypedDict",
    "BenefitDiscordCreate",
    "BenefitDiscordCreateProperties",
    "BenefitDiscordCreatePropertiesTypedDict",
    "BenefitDiscordCreateType",
    "BenefitDiscordCreateTypedDict",
    "BenefitDiscordInput",
    "BenefitDiscordInputType",
    "BenefitDiscordInputTypedDict",
    "BenefitDiscordOutput",
    "BenefitDiscordOutputType",
    "BenefitDiscordOutputTypedDict",
    "BenefitDiscordPropertiesInput",
    "BenefitDiscordPropertiesInputTypedDict",
    "BenefitDiscordPropertiesOutput",
    "BenefitDiscordPropertiesOutputTypedDict",
    "BenefitDiscordSubscriber",
    "BenefitDiscordSubscriberProperties",
    "BenefitDiscordSubscriberPropertiesTypedDict",
    "BenefitDiscordSubscriberType",
    "BenefitDiscordSubscriberTypedDict",
    "BenefitDiscordUpdate",
    "BenefitDiscordUpdateType",
    "BenefitDiscordUpdateTypedDict",
    "BenefitDownloadables",
    "BenefitDownloadablesCreate",
    "BenefitDownloadablesCreateProperties",
    "BenefitDownloadablesCreatePropertiesTypedDict",
    "BenefitDownloadablesCreateType",
    "BenefitDownloadablesCreateTypedDict",
    "BenefitDownloadablesProperties",
    "BenefitDownloadablesPropertiesTypedDict",
    "BenefitDownloadablesSubscriber",
    "BenefitDownloadablesSubscriberProperties",
    "BenefitDownloadablesSubscriberPropertiesTypedDict",
    "BenefitDownloadablesSubscriberType",
    "BenefitDownloadablesSubscriberTypedDict",
    "BenefitDownloadablesType",
    "BenefitDownloadablesTypedDict",
    "BenefitDownloadablesUpdate",
    "BenefitDownloadablesUpdateType",
    "BenefitDownloadablesUpdateTypedDict",
    "BenefitGitHubRepository",
    "BenefitGitHubRepositoryCreate",
    "BenefitGitHubRepositoryCreateProperties",
    "BenefitGitHubRepositoryCreatePropertiesPermission",
    "BenefitGitHubRepositoryCreatePropertiesTypedDict",
    "BenefitGitHubRepositoryCreateType",
    "BenefitGitHubRepositoryCreateTypedDict",
    "BenefitGitHubRepositoryProperties",
    "BenefitGitHubRepositoryPropertiesTypedDict",
    "BenefitGitHubRepositorySubscriber",
    "BenefitGitHubRepositorySubscriberProperties",
    "BenefitGitHubRepositorySubscriberPropertiesTypedDict",
    "BenefitGitHubRepositorySubscriberType",
    "BenefitGitHubRepositorySubscriberTypedDict",
    "BenefitGitHubRepositoryType",
    "BenefitGitHubRepositoryTypedDict",
    "BenefitGitHubRepositoryUpdate",
    "BenefitGitHubRepositoryUpdateType",
    "BenefitGitHubRepositoryUpdateTypedDict",
    "BenefitGrant",
    "BenefitGrantAds",
    "BenefitGrantAdsProperties",
    "BenefitGrantAdsPropertiesTypedDict",
    "BenefitGrantAdsTypedDict",
    "BenefitGrantLicenseKeys",
    "BenefitGrantLicenseKeysProperties",
    "BenefitGrantLicenseKeysPropertiesTypedDict",
    "BenefitGrantLicenseKeysTypedDict",
    "BenefitGrantProperties",
    "BenefitGrantPropertiesTypedDict",
    "BenefitGrantTypedDict",
    "BenefitIDFilter",
    "BenefitIDFilterTypedDict",
    "BenefitLicenseKeyActivationProperties",
    "BenefitLicenseKeyActivationPropertiesTypedDict",
    "BenefitLicenseKeyExpirationProperties",
    "BenefitLicenseKeyExpirationPropertiesTypedDict",
    "BenefitLicenseKeysCreate",
    "BenefitLicenseKeysCreateProperties",
    "BenefitLicenseKeysCreatePropertiesTypedDict",
    "BenefitLicenseKeysCreateType",
    "BenefitLicenseKeysCreateTypedDict",
    "BenefitLicenseKeysInput",
    "BenefitLicenseKeysInputType",
    "BenefitLicenseKeysInputTypedDict",
    "BenefitLicenseKeysOutput",
    "BenefitLicenseKeysOutputType",
    "BenefitLicenseKeysOutputTypedDict",
    "BenefitLicenseKeysProperties",
    "BenefitLicenseKeysPropertiesTypedDict",
    "BenefitLicenseKeysSubscriber",
    "BenefitLicenseKeysSubscriberProperties",
    "BenefitLicenseKeysSubscriberPropertiesTypedDict",
    "BenefitLicenseKeysSubscriberType",
    "BenefitLicenseKeysSubscriberTypedDict",
    "BenefitLicenseKeysUpdate",
    "BenefitLicenseKeysUpdateType",
    "BenefitLicenseKeysUpdateTypedDict",
    "BenefitType",
    "BenefitTypeFilter",
    "BenefitTypeFilterTypedDict",
    "BenefitTypedDict",
    "BenefitsCreateBenefitCreate",
    "BenefitsCreateBenefitCreateTypedDict",
    "BenefitsCreateResponseBenefitsCreate",
    "BenefitsCreateResponseBenefitsCreateTypedDict",
    "BenefitsDeleteRequest",
    "BenefitsDeleteRequestTypedDict",
    "BenefitsGetRequest",
    "BenefitsGetRequestTypedDict",
    "BenefitsGetResponseBenefitsGet",
    "BenefitsGetResponseBenefitsGetTypedDict",
    "BenefitsGrantsRequest",
    "BenefitsGrantsRequestTypedDict",
    "BenefitsGrantsResponse",
    "BenefitsGrantsResponseTypedDict",
    "BenefitsListQueryParamOrganizationIDFilter",
    "BenefitsListQueryParamOrganizationIDFilterTypedDict",
    "BenefitsListRequest",
    "BenefitsListRequestTypedDict",
    "BenefitsListResponse",
    "BenefitsListResponseTypedDict",
    "BenefitsModel",
    "BenefitsModelTypedDict",
    "BenefitsUpdateBenefitUpdate",
    "BenefitsUpdateBenefitUpdateTypedDict",
    "BenefitsUpdateRequest",
    "BenefitsUpdateRequestTypedDict",
    "BenefitsUpdateResponseBenefitsUpdate",
    "BenefitsUpdateResponseBenefitsUpdateTypedDict",
    "BylineProfile",
    "BylineProfileTypedDict",
    "Checkout",
    "CheckoutCreate",
    "CheckoutCreateTypedDict",
    "CheckoutTypedDict",
    "CheckoutsGetRequest",
    "CheckoutsGetRequestTypedDict",
    "Conditions",
    "ConditionsTypedDict",
    "CurrencyAmount",
    "CurrencyAmountTypedDict",
    "DonationInput",
    "DonationInputTypedDict",
    "DonationOrganization",
    "DonationOrganizationTypedDict",
    "DonationUser",
    "DonationUserTypedDict",
    "Donor",
    "DonorTypedDict",
    "DownloadableFileCreate",
    "DownloadableFileCreateService",
    "DownloadableFileCreateTypedDict",
    "DownloadableFileRead",
    "DownloadableFileReadService",
    "DownloadableFileReadTypedDict",
    "DownloadableRead",
    "DownloadableReadTypedDict",
    "ExistingProductPrice",
    "ExistingProductPriceTypedDict",
    "ExternalOrganization",
    "ExternalOrganizationNameFilter",
    "ExternalOrganizationNameFilterTypedDict",
    "ExternalOrganizationSortProperty",
    "ExternalOrganizationTypedDict",
    "ExternalOrganizationsListQueryParamOrganizationIDFilter",
    "ExternalOrganizationsListQueryParamOrganizationIDFilterTypedDict",
    "ExternalOrganizationsListRequest",
    "ExternalOrganizationsListRequestTypedDict",
    "ExternalOrganizationsListResponse",
    "ExternalOrganizationsListResponseTypedDict",
    "FileDownload",
    "FileDownloadTypedDict",
    "FileNotFound",
    "FileNotFoundData",
    "FileNotFoundType",
    "FilePatch",
    "FilePatchTypedDict",
    "FileRead",
    "FileReadTypedDict",
    "FileServiceTypes",
    "FileUpload",
    "FileUploadCompleted",
    "FileUploadCompletedTypedDict",
    "FileUploadTypedDict",
    "FilesCreateFileCreate",
    "FilesCreateFileCreateTypedDict",
    "FilesDeleteRequest",
    "FilesDeleteRequestTypedDict",
    "FilesListRequest",
    "FilesListRequestTypedDict",
    "FilesListResponse",
    "FilesListResponseTypedDict",
    "FilesUpdateRequest",
    "FilesUpdateRequestTypedDict",
    "FilesUpdateResponseFilesUpdate",
    "FilesUpdateResponseFilesUpdateTypedDict",
    "FilesUploadedRequest",
    "FilesUploadedRequestTypedDict",
    "FilesUploadedResponseFilesUploaded",
    "FilesUploadedResponseFilesUploadedTypedDict",
    "Funding",
    "FundingTypedDict",
    "GrantType",
    "GrantTypes",
    "HTTPValidationError",
    "HTTPValidationErrorData",
    "Interval",
    "IntrospectTokenResponse",
    "IntrospectTokenResponseTokenType",
    "IntrospectTokenResponseTypedDict",
    "IssueInput",
    "IssueInputTypedDict",
    "Label",
    "LabelTypedDict",
    "LicenseKeyActivate",
    "LicenseKeyActivateConditions",
    "LicenseKeyActivateConditionsTypedDict",
    "LicenseKeyActivateMeta",
    "LicenseKeyActivateMetaTypedDict",
    "LicenseKeyActivateTypedDict",
    "LicenseKeyActivationBase",
    "LicenseKeyActivationBaseTypedDict",
    "LicenseKeyActivationRead",
    "LicenseKeyActivationReadMeta",
    "LicenseKeyActivationReadMetaTypedDict",
    "LicenseKeyActivationReadTypedDict",
    "LicenseKeyDeactivate",
    "LicenseKeyDeactivateTypedDict",
    "LicenseKeyRead",
    "LicenseKeyReadTypedDict",
    "LicenseKeyStatus",
    "LicenseKeyUpdate",
    "LicenseKeyUpdateTypedDict",
    "LicenseKeyValidate",
    "LicenseKeyValidateTypedDict",
    "LicenseKeyWithActivations",
    "LicenseKeyWithActivationsTypedDict",
    "LicenseKeysGetActivationRequest",
    "LicenseKeysGetActivationRequestTypedDict",
    "LicenseKeysGetRequest",
    "LicenseKeysGetRequestTypedDict",
    "LicenseKeysListQueryParamOrganizationIDFilter",
    "LicenseKeysListQueryParamOrganizationIDFilterTypedDict",
    "LicenseKeysListRequest",
    "LicenseKeysListRequestTypedDict",
    "LicenseKeysListResponse",
    "LicenseKeysListResponseTypedDict",
    "LicenseKeysUpdateRequest",
    "LicenseKeysUpdateRequestTypedDict",
    "ListResourceArticle",
    "ListResourceArticleTypedDict",
    "ListResourceBenefit",
    "ListResourceBenefitGrant",
    "ListResourceBenefitGrantTypedDict",
    "ListResourceBenefitTypedDict",
    "ListResourceDownloadableRead",
    "ListResourceDownloadableReadTypedDict",
    "ListResourceExternalOrganization",
    "ListResourceExternalOrganizationTypedDict",
    "ListResourceFileRead",
    "ListResourceFileReadTypedDict",
    "ListResourceLicenseKeyRead",
    "ListResourceLicenseKeyReadTypedDict",
    "ListResourceOAuth2Client",
    "ListResourceOAuth2ClientTypedDict",
    "ListResourceOrder",
    "ListResourceOrderTypedDict",
    "ListResourceOrganization",
    "ListResourceOrganizationTypedDict",
    "ListResourceProduct",
    "ListResourceProductTypedDict",
    "ListResourceRepository",
    "ListResourceRepositoryTypedDict",
    "ListResourceSubscription",
    "ListResourceSubscriptionTypedDict",
    "ListResourceUserAdvertisementCampaign",
    "ListResourceUserAdvertisementCampaignTypedDict",
    "ListResourceUserBenefit",
    "ListResourceUserBenefitTypedDict",
    "ListResourceUserOrder",
    "ListResourceUserOrderTypedDict",
    "ListResourceUserSubscription",
    "ListResourceUserSubscriptionTypedDict",
    "Loc",
    "LocTypedDict",
    "Meta",
    "MetaTypedDict",
    "Metric",
    "MetricPeriod",
    "MetricPeriodTypedDict",
    "MetricType",
    "MetricTypedDict",
    "Metrics",
    "MetricsGetQueryParamOrganizationIDFilter",
    "MetricsGetQueryParamOrganizationIDFilterTypedDict",
    "MetricsGetQueryParamProductIDFilter",
    "MetricsGetQueryParamProductIDFilterTypedDict",
    "MetricsGetQueryParamProductPriceTypeFilter",
    "MetricsGetQueryParamProductPriceTypeFilterTypedDict",
    "MetricsGetRequest",
    "MetricsGetRequestTypedDict",
    "MetricsIntervalLimit",
    "MetricsIntervalLimitTypedDict",
    "MetricsIntervalsLimits",
    "MetricsIntervalsLimitsTypedDict",
    "MetricsLimits",
    "MetricsLimitsTypedDict",
    "MetricsResponse",
    "MetricsResponseTypedDict",
    "MetricsTypedDict",
    "NotPermitted",
    "NotPermittedData",
    "NotPermittedType",
    "OAuth2Client",
    "OAuth2ClientConfiguration",
    "OAuth2ClientConfigurationGrantTypes",
    "OAuth2ClientConfigurationResponseTypes",
    "OAuth2ClientConfigurationTokenEndpointAuthMethod",
    "OAuth2ClientConfigurationTypedDict",
    "OAuth2ClientConfigurationUpdate",
    "OAuth2ClientConfigurationUpdateGrantTypes",
    "OAuth2ClientConfigurationUpdateResponseTypes",
    "OAuth2ClientConfigurationUpdateTokenEndpointAuthMethod",
    "OAuth2ClientConfigurationUpdateTypedDict",
    "OAuth2ClientTypedDict",
    "Oauth2ClientsListRequest",
    "Oauth2ClientsListRequestTypedDict",
    "Oauth2ClientsListResponse",
    "Oauth2ClientsListResponseTypedDict",
    "Oauth2ClientsOauth2DeleteClientRequest",
    "Oauth2ClientsOauth2DeleteClientRequestTypedDict",
    "Oauth2ClientsOauth2GetClientRequest",
    "Oauth2ClientsOauth2GetClientRequestTypedDict",
    "Oauth2ClientsOauth2UpdateClientRequest",
    "Oauth2ClientsOauth2UpdateClientRequestTypedDict",
    "Oauth2IntrospectTokenIntrospectTokenRequest",
    "Oauth2IntrospectTokenIntrospectTokenRequestTypedDict",
    "Oauth2IntrospectTokenTokenTypeHint",
    "Oauth2RequestTokenRequestBody",
    "Oauth2RequestTokenRequestBodyTypedDict",
    "Oauth2RevokeTokenRevokeTokenRequest",
    "Oauth2RevokeTokenRevokeTokenRequestTypedDict",
    "Oauth2UserinfoResponseOauth2Userinfo",
    "Oauth2UserinfoResponseOauth2UserinfoTypedDict",
    "Onev11oauth21tokenPostXComponentsAuthorizationCodeTokenRequest",
    "Onev11oauth21tokenPostXComponentsAuthorizationCodeTokenRequestTypedDict",
    "Onev11oauth21tokenPostXComponentsRefreshTokenRequest",
    "Onev11oauth21tokenPostXComponentsRefreshTokenRequestGrantType",
    "Onev11oauth21tokenPostXComponentsRefreshTokenRequestTypedDict",
    "OrderIDFilter",
    "OrderIDFilterTypedDict",
    "OrderInput",
    "OrderInputTypedDict",
    "OrderInvoice",
    "OrderInvoiceTypedDict",
    "OrderOutput",
    "OrderOutputTypedDict",
    "OrderProduct",
    "OrderProductTypedDict",
    "OrderSortProperty",
    "OrderSubscription",
    "OrderSubscriptionTypedDict",
    "OrderUser",
    "OrderUserTypedDict",
    "OrdersGetRequest",
    "OrdersGetRequestTypedDict",
    "OrdersInvoiceRequest",
    "OrdersInvoiceRequestTypedDict",
    "OrdersListQueryParamOrganizationIDFilter",
    "OrdersListQueryParamOrganizationIDFilterTypedDict",
    "OrdersListQueryParamProductIDFilter",
    "OrdersListQueryParamProductIDFilterTypedDict",
    "OrdersListRequest",
    "OrdersListRequestTypedDict",
    "OrdersListResponse",
    "OrdersListResponseTypedDict",
    "OrganizationAvatarFileCreate",
    "OrganizationAvatarFileCreateService",
    "OrganizationAvatarFileCreateTypedDict",
    "OrganizationAvatarFileRead",
    "OrganizationAvatarFileReadService",
    "OrganizationAvatarFileReadTypedDict",
    "OrganizationCreate",
    "OrganizationCreateTypedDict",
    "OrganizationFeatureSettings",
    "OrganizationFeatureSettingsTypedDict",
    "OrganizationID",
    "OrganizationIDFilter",
    "OrganizationIDFilterTypedDict",
    "OrganizationIDTypedDict",
    "OrganizationInput",
    "OrganizationInputTypedDict",
    "OrganizationOutput",
    "OrganizationOutputTypedDict",
    "OrganizationProfileSettings",
    "OrganizationProfileSettingsTypedDict",
    "OrganizationSortProperty",
    "OrganizationSubscribePromoteSettings",
    "OrganizationSubscribePromoteSettingsTypedDict",
    "OrganizationUpdate",
    "OrganizationUpdateTypedDict",
    "OrganizationsGetRequest",
    "OrganizationsGetRequestTypedDict",
    "OrganizationsListRequest",
    "OrganizationsListRequestTypedDict",
    "OrganizationsListResponse",
    "OrganizationsListResponseTypedDict",
    "OrganizationsUpdateRequest",
    "OrganizationsUpdateRequestTypedDict",
    "Pagination",
    "PaginationTypedDict",
    "Permission",
    "PlatformFilter",
    "PlatformFilterTypedDict",
    "Platforms",
    "PledgeInput",
    "PledgeInputTypedDict",
    "PledgeState",
    "PledgeType",
    "Pledger",
    "PledgerTypedDict",
    "Prices",
    "PricesTypedDict",
    "ProductBenefitsUpdate",
    "ProductBenefitsUpdateTypedDict",
    "ProductIDFilter",
    "ProductIDFilterTypedDict",
    "ProductInput",
    "ProductInputBenefits",
    "ProductInputBenefitsTypedDict",
    "ProductInputTypedDict",
    "ProductMediaFileCreate",
    "ProductMediaFileCreateService",
    "ProductMediaFileCreateTypedDict",
    "ProductMediaFileReadInput",
    "ProductMediaFileReadInputService",
    "ProductMediaFileReadInputTypedDict",
    "ProductMediaFileReadOutput",
    "ProductMediaFileReadOutputTypedDict",
    "ProductOneTimeCreate",
    "ProductOneTimeCreateTypedDict",
    "ProductOutput",
    "ProductOutputBenefits",
    "ProductOutputBenefitsTypedDict",
    "ProductOutputTypedDict",
    "ProductPriceInput",
    "ProductPriceInputTypedDict",
    "ProductPriceOneTime",
    "ProductPriceOneTimeCustom",
    "ProductPriceOneTimeCustomAmountType",
    "ProductPriceOneTimeCustomCreate",
    "ProductPriceOneTimeCustomCreateAmountType",
    "ProductPriceOneTimeCustomCreateType",
    "ProductPriceOneTimeCustomCreateTypedDict",
    "ProductPriceOneTimeCustomType",
    "ProductPriceOneTimeCustomTypedDict",
    "ProductPriceOneTimeFixed",
    "ProductPriceOneTimeFixedAmountType",
    "ProductPriceOneTimeFixedCreate",
    "ProductPriceOneTimeFixedCreateAmountType",
    "ProductPriceOneTimeFixedCreateType",
    "ProductPriceOneTimeFixedCreateTypedDict",
    "ProductPriceOneTimeFixedType",
    "ProductPriceOneTimeFixedTypedDict",
    "ProductPriceOneTimeFree",
    "ProductPriceOneTimeFreeAmountType",
    "ProductPriceOneTimeFreeCreate",
    "ProductPriceOneTimeFreeCreateAmountType",
    "ProductPriceOneTimeFreeCreateType",
    "ProductPriceOneTimeFreeCreateTypedDict",
    "ProductPriceOneTimeFreeType",
    "ProductPriceOneTimeFreeTypedDict",
    "ProductPriceOneTimeTypedDict",
    "ProductPriceOutput",
    "ProductPriceOutputTypedDict",
    "ProductPriceRecurringCustom",
    "ProductPriceRecurringCustomAmountType",
    "ProductPriceRecurringCustomType",
    "ProductPriceRecurringCustomTypedDict",
    "ProductPriceRecurringFixed",
    "ProductPriceRecurringFixedCreate",
    "ProductPriceRecurringFixedCreateAmountType",
    "ProductPriceRecurringFixedCreateType",
    "ProductPriceRecurringFixedCreateTypedDict",
    "ProductPriceRecurringFixedType",
    "ProductPriceRecurringFixedTypedDict",
    "ProductPriceRecurringFree",
    "ProductPriceRecurringFreeAmountType",
    "ProductPriceRecurringFreeCreate",
    "ProductPriceRecurringFreeCreateAmountType",
    "ProductPriceRecurringFreeCreateType",
    "ProductPriceRecurringFreeCreateTypedDict",
    "ProductPriceRecurringFreeType",
    "ProductPriceRecurringFreeTypedDict",
    "ProductPriceRecurringInput",
    "ProductPriceRecurringInputTypedDict",
    "ProductPriceRecurringOutput",
    "ProductPriceRecurringOutputTypedDict",
    "ProductPriceType",
    "ProductPriceTypeFilter",
    "ProductPriceTypeFilterTypedDict",
    "ProductRecurringCreate",
    "ProductRecurringCreatePrices",
    "ProductRecurringCreatePricesTypedDict",
    "ProductRecurringCreateTypedDict",
    "ProductUpdate",
    "ProductUpdatePrices",
    "ProductUpdatePricesTypedDict",
    "ProductUpdateTypedDict",
    "ProductsCreateProductCreate",
    "ProductsCreateProductCreateTypedDict",
    "ProductsGetRequest",
    "ProductsGetRequestTypedDict",
    "ProductsListQueryParamOrganizationIDFilter",
    "ProductsListQueryParamOrganizationIDFilterTypedDict",
    "ProductsListRequest",
    "ProductsListRequestTypedDict",
    "ProductsListResponse",
    "ProductsListResponseTypedDict",
    "ProductsUpdateBenefitsRequest",
    "ProductsUpdateBenefitsRequestTypedDict",
    "ProductsUpdateRequest",
    "ProductsUpdateRequestTypedDict",
    "QueryParamBenefitIDFilter",
    "QueryParamBenefitIDFilterTypedDict",
    "QueryParamBenefitTypeFilter",
    "QueryParamBenefitTypeFilterTypedDict",
    "QueryParamOrganizationIDFilter",
    "QueryParamOrganizationIDFilterTypedDict",
    "QueryParamPlatformFilter",
    "QueryParamPlatformFilterTypedDict",
    "QueryParamProductIDFilter",
    "QueryParamProductIDFilterTypedDict",
    "QueryParamProductPriceTypeFilter",
    "QueryParamProductPriceTypeFilterTypedDict",
    "QueryParamRepositoryNameFilter",
    "QueryParamRepositoryNameFilterTypedDict",
    "QueryParamSubscriptionIDFilter",
    "QueryParamSubscriptionIDFilterTypedDict",
    "Reactions",
    "ReactionsTypedDict",
    "RepositoriesGetRequest",
    "RepositoriesGetRequestTypedDict",
    "RepositoriesListQueryParamOrganizationIDFilter",
    "RepositoriesListQueryParamOrganizationIDFilterTypedDict",
    "RepositoriesListRequest",
    "RepositoriesListRequestTypedDict",
    "RepositoriesListResponse",
    "RepositoriesListResponseTypedDict",
    "RepositoriesUpdateRequest",
    "RepositoriesUpdateRequestTypedDict",
    "RepositoryInput",
    "RepositoryInputTypedDict",
    "RepositoryNameFilter",
    "RepositoryNameFilterTypedDict",
    "RepositoryOutput",
    "RepositoryOutputTypedDict",
    "RepositoryProfileSettings",
    "RepositoryProfileSettingsTypedDict",
    "RepositoryProfileSettingsUpdate",
    "RepositoryProfileSettingsUpdateTypedDict",
    "RepositorySortProperty",
    "RepositoryUpdate",
    "RepositoryUpdateTypedDict",
    "ResourceNotFound",
    "ResourceNotFoundData",
    "ResourceNotFoundType",
    "ResponseTypes",
    "RevokeTokenResponse",
    "RevokeTokenResponseTypedDict",
    "S3DownloadURL",
    "S3DownloadURLTypedDict",
    "S3FileCreateMultipart",
    "S3FileCreateMultipartTypedDict",
    "S3FileCreatePart",
    "S3FileCreatePartTypedDict",
    "S3FileUploadCompletedPart",
    "S3FileUploadCompletedPartTypedDict",
    "S3FileUploadMultipart",
    "S3FileUploadMultipartTypedDict",
    "S3FileUploadPart",
    "S3FileUploadPartTypedDict",
    "SDKError",
    "Security",
    "SecurityTypedDict",
    "Service",
    "State",
    "SubType",
    "SubscriptionIDFilter",
    "SubscriptionIDFilterTypedDict",
    "SubscriptionInput",
    "SubscriptionInputTypedDict",
    "SubscriptionOutput",
    "SubscriptionOutputTypedDict",
    "SubscriptionRecurringInterval",
    "SubscriptionSortProperty",
    "SubscriptionStatus",
    "SubscriptionUser",
    "SubscriptionUserTypedDict",
    "SubscriptionsExportRequest",
    "SubscriptionsExportRequestTypedDict",
    "SubscriptionsListQueryParamOrganizationIDFilter",
    "SubscriptionsListQueryParamOrganizationIDFilterTypedDict",
    "SubscriptionsListQueryParamProductIDFilter",
    "SubscriptionsListQueryParamProductIDFilterTypedDict",
    "SubscriptionsListRequest",
    "SubscriptionsListRequestTypedDict",
    "SubscriptionsListResponse",
    "SubscriptionsListResponseTypedDict",
    "Timeframe",
    "TokenEndpointAuthMethod",
    "TokenResponse",
    "TokenResponseTypedDict",
    "TokenType",
    "TokenTypeHint",
    "Type",
    "Unauthorized",
    "UnauthorizedData",
    "UnauthorizedType",
    "UserAdvertisementCampaign",
    "UserAdvertisementCampaignCreate",
    "UserAdvertisementCampaignCreateTypedDict",
    "UserAdvertisementCampaignEnable",
    "UserAdvertisementCampaignEnableTypedDict",
    "UserAdvertisementCampaignTypedDict",
    "UserAdvertisementCampaignUpdate",
    "UserAdvertisementCampaignUpdateTypedDict",
    "UserAdvertisementSortProperty",
    "UserBenefit",
    "UserBenefitSortProperty",
    "UserBenefitTypedDict",
    "UserIDFilter",
    "UserIDFilterTypedDict",
    "UserInfoOrganization",
    "UserInfoOrganizationTypedDict",
    "UserInfoUser",
    "UserInfoUserTypedDict",
    "UserOrder",
    "UserOrderInvoice",
    "UserOrderInvoiceTypedDict",
    "UserOrderProduct",
    "UserOrderProductTypedDict",
    "UserOrderSortProperty",
    "UserOrderSubscription",
    "UserOrderSubscriptionTypedDict",
    "UserOrderTypedDict",
    "UserSubscription",
    "UserSubscriptionProduct",
    "UserSubscriptionProductBenefits",
    "UserSubscriptionProductBenefitsTypedDict",
    "UserSubscriptionProductTypedDict",
    "UserSubscriptionSortProperty",
    "UserSubscriptionTypedDict",
    "UserSubscriptionUpdate",
    "UserSubscriptionUpdateTypedDict",
    "UsersAdvertisementsDeleteRequest",
    "UsersAdvertisementsDeleteRequestTypedDict",
    "UsersAdvertisementsEnableRequest",
    "UsersAdvertisementsEnableRequestTypedDict",
    "UsersAdvertisementsGetRequest",
    "UsersAdvertisementsGetRequestTypedDict",
    "UsersAdvertisementsListRequest",
    "UsersAdvertisementsListRequestTypedDict",
    "UsersAdvertisementsListResponse",
    "UsersAdvertisementsListResponseTypedDict",
    "UsersAdvertisementsUpdateRequest",
    "UsersAdvertisementsUpdateRequestTypedDict",
    "UsersBenefitsGetRequest",
    "UsersBenefitsGetRequestTypedDict",
    "UsersBenefitsGetResponseUsersBenefitsGet",
    "UsersBenefitsGetResponseUsersBenefitsGetTypedDict",
    "UsersBenefitsListRequest",
    "UsersBenefitsListRequestTypedDict",
    "UsersBenefitsListResponse",
    "UsersBenefitsListResponseTypedDict",
    "UsersDownloadablesGetRequest",
    "UsersDownloadablesGetRequestTypedDict",
    "UsersDownloadablesListQueryParamOrganizationIDFilter",
    "UsersDownloadablesListQueryParamOrganizationIDFilterTypedDict",
    "UsersDownloadablesListRequest",
    "UsersDownloadablesListRequestTypedDict",
    "UsersDownloadablesListResponse",
    "UsersDownloadablesListResponseTypedDict",
    "UsersLicenseKeysGetRequest",
    "UsersLicenseKeysGetRequestTypedDict",
    "UsersLicenseKeysListQueryParamOrganizationIDFilter",
    "UsersLicenseKeysListQueryParamOrganizationIDFilterTypedDict",
    "UsersLicenseKeysListRequest",
    "UsersLicenseKeysListRequestTypedDict",
    "UsersLicenseKeysListResponse",
    "UsersLicenseKeysListResponseTypedDict",
    "UsersOrdersGetRequest",
    "UsersOrdersGetRequestTypedDict",
    "UsersOrdersInvoiceRequest",
    "UsersOrdersInvoiceRequestTypedDict",
    "UsersOrdersListRequest",
    "UsersOrdersListRequestTypedDict",
    "UsersOrdersListResponse",
    "UsersOrdersListResponseTypedDict",
    "UsersSubscriptionsCancelRequest",
    "UsersSubscriptionsCancelRequestTypedDict",
    "UsersSubscriptionsGetRequest",
    "UsersSubscriptionsGetRequestTypedDict",
    "UsersSubscriptionsListQueryParamOrganizationIDFilter",
    "UsersSubscriptionsListQueryParamOrganizationIDFilterTypedDict",
    "UsersSubscriptionsListRequest",
    "UsersSubscriptionsListRequestTypedDict",
    "UsersSubscriptionsListResponse",
    "UsersSubscriptionsListResponseTypedDict",
    "UsersSubscriptionsUpdateRequest",
    "UsersSubscriptionsUpdateRequestTypedDict",
    "ValidatedLicenseKey",
    "ValidatedLicenseKeyTypedDict",
    "ValidationError",
    "ValidationErrorTypedDict",
    "WebhookBenefitCreatedPayload",
    "WebhookBenefitCreatedPayloadBenefit",
    "WebhookBenefitCreatedPayloadBenefitTypedDict",
    "WebhookBenefitCreatedPayloadType",
    "WebhookBenefitCreatedPayloadTypedDict",
    "WebhookBenefitUpdatedPayload",
    "WebhookBenefitUpdatedPayloadBenefit",
    "WebhookBenefitUpdatedPayloadBenefitTypedDict",
    "WebhookBenefitUpdatedPayloadType",
    "WebhookBenefitUpdatedPayloadTypedDict",
    "WebhookDonationCreatedPayload",
    "WebhookDonationCreatedPayloadType",
    "WebhookDonationCreatedPayloadTypedDict",
    "WebhookOrderCreatedPayload",
    "WebhookOrderCreatedPayloadType",
    "WebhookOrderCreatedPayloadTypedDict",
    "WebhookOrganizationUpdatedPayload",
    "WebhookOrganizationUpdatedPayloadType",
    "WebhookOrganizationUpdatedPayloadTypedDict",
    "WebhookPledgeCreatedPayload",
    "WebhookPledgeCreatedPayloadType",
    "WebhookPledgeCreatedPayloadTypedDict",
    "WebhookPledgeUpdatedPayload",
    "WebhookPledgeUpdatedPayloadType",
    "WebhookPledgeUpdatedPayloadTypedDict",
    "WebhookProductCreatedPayload",
    "WebhookProductCreatedPayloadType",
    "WebhookProductCreatedPayloadTypedDict",
    "WebhookProductUpdatedPayload",
    "WebhookProductUpdatedPayloadType",
    "WebhookProductUpdatedPayloadTypedDict",
    "WebhookSubscriptionCreatedPayload",
    "WebhookSubscriptionCreatedPayloadType",
    "WebhookSubscriptionCreatedPayloadTypedDict",
    "WebhookSubscriptionUpdatedPayload",
    "WebhookSubscriptionUpdatedPayloadType",
    "WebhookSubscriptionUpdatedPayloadTypedDict",
]



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .metrictype import MetricType
from polar_sdk.types import BaseModel
from typing import TypedDict


class MetricTypedDict(TypedDict):
    r"""Information about a metric."""

    slug: str
    r"""Unique identifier for the metric."""
    display_name: str
    r"""Human-readable name for the metric."""
    type: MetricType
    r"""Type of the metric, useful to know the unit or format of the value."""


class Metric(BaseModel):
    r"""Information about a metric."""

    slug: str
    r"""Unique identifier for the metric."""

    display_name: str
    r"""Human-readable name for the metric."""

    type: MetricType
    r"""Type of the metric, useful to know the unit or format of the value."""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .product_input import ProductInput, ProductInputTypedDict
from enum import Enum
from polar_sdk.types import BaseModel
import pydantic
from typing import Final, TypedDict
from typing_extensions import Annotated


class WebhookProductUpdatedPayloadType(str, Enum):
    PRODUCT_UPDATED = "product.updated"


class WebhookProductUpdatedPayloadTypedDict(TypedDict):
    r"""Sent when a product is updated.

    **Discord & Slack support:** Basic
    """

    data: ProductInputTypedDict
    r"""A product."""
    type: WebhookProductUpdatedPayloadType


class WebhookProductUpdatedPayload(BaseModel):
    r"""Sent when a product is updated.

    **Discord & Slack support:** Basic
    """

    data: ProductInput
    r"""A product."""

    # fmt: off
    TYPE: Annotated[Final[WebhookProductUpdatedPayloadType], pydantic.Field(alias="type")] = WebhookProductUpdatedPayloadType.PRODUCT_UPDATED # type: ignore
    # fmt: on



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum
from polar_sdk import utils
from polar_sdk.types import BaseModel
import pydantic
from typing import Final
from typing_extensions import Annotated


class UnauthorizedType(str, Enum):
    UNAUTHORIZED = "Unauthorized"


class UnauthorizedData(BaseModel):
    detail: str

    # fmt: off
    TYPE: Annotated[Final[UnauthorizedType], pydantic.Field(alias="type")] = UnauthorizedType.UNAUTHORIZED # type: ignore
    # fmt: on


class Unauthorized(Exception):
    r"""Not authorized to manage license key."""

    data: UnauthorizedData

    def __init__(self, data: UnauthorizedData):
        self.data = data

    def __str__(self) -> str:
        return utils.marshal_json(self.data, UnauthorizedData)



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from polar_sdk.types import BaseModel
from typing import TypedDict


class ExistingProductPriceTypedDict(TypedDict):
    r"""A price that already exists for this product.

    Useful when updating a product if you want to keep an existing price.
    """

    id: str


class ExistingProductPrice(BaseModel):
    r"""A price that already exists for this product.

    Useful when updating a product if you want to keep an existing price.
    """

    id: str



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .donationorganization import DonationOrganization, DonationOrganizationTypedDict
from .donationuser import DonationUser, DonationUserTypedDict
from .issue_input import IssueInput, IssueInputTypedDict
from datetime import datetime
from polar_sdk.types import BaseModel, Nullable, UNSET_SENTINEL
from pydantic import model_serializer
from typing import TypedDict, Union


DonorTypedDict = Union[DonationUserTypedDict, DonationOrganizationTypedDict]


Donor = Union[DonationUser, DonationOrganization]


class DonationInputTypedDict(TypedDict):
    created_at: datetime
    r"""Creation timestamp of the object."""
    modified_at: Nullable[datetime]
    r"""Last modification timestamp of the object."""
    id: str
    r"""The ID of the object."""
    amount: int
    currency: str
    message: Nullable[str]
    donor: Nullable[DonorTypedDict]
    email: str
    issue: Nullable[IssueInputTypedDict]


class DonationInput(BaseModel):
    created_at: datetime
    r"""Creation timestamp of the object."""

    modified_at: Nullable[datetime]
    r"""Last modification timestamp of the object."""

    id: str
    r"""The ID of the object."""

    amount: int

    currency: str

    message: Nullable[str]

    donor: Nullable[Donor]

    email: str

    issue: Nullable[IssueInput]

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = []
        nullable_fields = ["modified_at", "message", "donor", "issue"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in self.model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .benefitads import BenefitAds, BenefitAdsTypedDict
from .benefitarticles import BenefitArticles, BenefitArticlesTypedDict
from .benefitcustom import BenefitCustom, BenefitCustomTypedDict
from .benefitdiscord_output import BenefitDiscordOutput, BenefitDiscordOutputTypedDict
from .benefitdownloadables import BenefitDownloadables, BenefitDownloadablesTypedDict
from .benefitgithubrepository import (
    BenefitGitHubRepository,
    BenefitGitHubRepositoryTypedDict,
)
from .benefitlicensekeys_output import (
    BenefitLicenseKeysOutput,
    BenefitLicenseKeysOutputTypedDict,
)
from polar_sdk.types import BaseModel
from polar_sdk.utils import FieldMetadata, PathParamMetadata
from typing import TypedDict, Union
from typing_extensions import Annotated


class BenefitsGetRequestTypedDict(TypedDict):
    id: str


class BenefitsGetRequest(BaseModel):
    id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]


BenefitsGetResponseBenefitsGetTypedDict = Union[
    BenefitArticlesTypedDict,
    BenefitAdsTypedDict,
    BenefitDiscordOutputTypedDict,
    BenefitGitHubRepositoryTypedDict,
    BenefitDownloadablesTypedDict,
    BenefitLicenseKeysOutputTypedDict,
    BenefitCustomTypedDict,
]
r"""Successful Response"""


BenefitsGetResponseBenefitsGet = Union[
    BenefitArticles,
    BenefitAds,
    BenefitDiscordOutput,
    BenefitGitHubRepository,
    BenefitDownloadables,
    BenefitLicenseKeysOutput,
    BenefitCustom,
]
r"""Successful Response"""
